﻿using IoTSharp.Dtos;
using Microsoft.AspNetCore.Identity;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.Logging;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Security.Claims;
using System.Threading.Tasks;
using IoTSharp.Models.FormFieldTypes;

namespace IoTSharp.Data
{
    public class ApplicationDBInitializer
    {
        private readonly RoleManager<IdentityRole> _role;

        private ApplicationDbContext _context;
        private ILogger _logger;
        private readonly UserManager<IdentityUser> _userManager;
        private readonly IConfiguration _configuration;
        private readonly SignInManager<IdentityUser> _signInManager;

        public ApplicationDBInitializer(
            UserManager<IdentityUser> userManager,
            SignInManager<IdentityUser> signInManager,
            IConfiguration configuration, ILogger<ApplicationDBInitializer> logger,
            ApplicationDbContext context, RoleManager<IdentityRole> role
            )
        {
            _userManager = userManager;
            _signInManager = signInManager;
            _configuration = configuration;
            _logger = logger;
            _context = context;
            _role = role;
        }

        public async Task SeedRoleAsync()
        {
            var roles = new IdentityRole[]{new IdentityRole(nameof(UserRole.Anonymous))
                    , new IdentityRole(nameof(UserRole.NormalUser))
                    , new IdentityRole(nameof(UserRole.CustomerAdmin))
                    , new IdentityRole(nameof(UserRole.TenantAdmin))
                    , new IdentityRole(nameof(UserRole.SystemAdmin)) };
            foreach (var role in roles)
            {
                if (!await _role.RoleExistsAsync(role.Name))
                {
                    if ((await _role.CreateAsync(role)).Succeeded)
                    {
                        await _role.UpdateNormalizedRoleNameAsync(role);
                    }
                };
            }
        }

        public async Task SeedI18N()
        {

            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.fullscreen", ValueENUS = "Fullscreen", ValueFRFR = "Plein écran", ValueHRHR = "Puni zaslon", ValueKOKR = "전체 화면", ValuePLPL = "Pełny ekran", ValueSLSL = "Celozaslonski način", ValueTRTR = "Tam Ekran", ValueZHCN = "全屏", ValueZHTW = "全屏", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "column.columns.columname", ValueENUS = "Column name", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "栏目名称", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.form.new.title", ValueENUS = "New Resource", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "新增资源", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.devtype.propsave", ValueENUS = "Property settings", ValueFRFR = "Paramètres de propriété", ValueHRHR = "", ValueKOKR = "속성 설정", ValuePLPL = "Ustawienia właściwości", ValueSLSL = "Nastavitve lastnosti", ValueTRTR = "", ValueZHCN = "属性设置", ValueZHTW = "内容設定", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "button.active", ValueENUS = "activation", ValueFRFR = "Activation", ValueHRHR = "", ValueKOKR = "활성화 하 다.", ValuePLPL = "aktywacja", ValueSLSL = "aktivacija", ValueTRTR = "", ValueZHCN = "激活", ValueZHTW = "啟動", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "common.paramsettting", ValueENUS = "Parameter setting", ValueFRFR = "Paramètres", ValueHRHR = "", ValueKOKR = "매개 변수 설정", ValuePLPL = "Ustawienie parametrów", ValueSLSL = "Nastavitev parametrov", ValueTRTR = "", ValueZHCN = "参数设置", ValueZHTW = "參數設置", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.search.placeholder", ValueENUS = "Search for people, file, photos...", ValueFRFR = "Rechercher des personnes, des fichiers, des photos ...", ValueHRHR = "Traži osobe, datoteke, fotografije ...", ValueKOKR = "사람, 파일, 사진 검색...", ValuePLPL = "Szukaj osób, plików, zdjęć...", ValueSLSL = "Išči ljudi, datoteke, fotografije,...", ValueTRTR = "Kişileri, dosyaları, fotografları... ara", ValueZHCN = "搜索：员工、文件、照片等", ValueZHTW = "搜索：員工、文件、照片等", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.fullscreen.exit", ValueENUS = "Exit Fullscreen", ValueFRFR = "Quitter le mode plein écran", ValueHRHR = "Izađite sa cijelog zaslona", ValueKOKR = "전체 화면 종료", ValuePLPL = "Wyjdź z pełnego ekranu", ValueSLSL = "Zapusti celozaslonski način", ValueTRTR = "Tam Ekrandan Çık", ValueZHCN = "退出全屏", ValueZHTW = "退出全屏", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.clear.local.storage", ValueENUS = "Clear Local Storage", ValueFRFR = "Effacer le stockage local", ValueHRHR = "Očistite lokalnu pohranu", ValueKOKR = "로컬 저장소 지우기", ValuePLPL = "Wyczyść magazyn lokalny", ValueSLSL = "Izbriši lokalni pomnilnik", ValueTRTR = "Yerel Depolama Alanını Temizle", ValueZHCN = "清理本地缓存", ValueZHTW = "清理在地緩存", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.lang", ValueENUS = "Language", ValueFRFR = "Langue", ValueHRHR = "Jezik", ValueKOKR = "언어", ValuePLPL = "Język", ValueSLSL = "Jezik", ValueTRTR = "Dil", ValueZHCN = "语言", ValueZHTW = "語言", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.main", ValueENUS = "Main Navigation", ValueFRFR = "Navigation principale", ValueHRHR = "Glavna navigacija", ValueKOKR = "기본 탐색", ValuePLPL = "Główna nawigacja", ValueSLSL = "Glavna navigacija", ValueTRTR = "Ana Menü", ValueZHCN = "主导航", ValueZHTW = "主導航", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.dashboard", ValueENUS = "Dashboard", ValueFRFR = "Tableau de bord", ValueHRHR = "Ploča", ValueKOKR = "대시 보드", ValuePLPL = "Dashboard", ValueSLSL = "Glavni vmesnik", ValueTRTR = "Panel", ValueZHCN = "仪表盘", ValueZHTW = "儀錶盤", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.dashboard.v1", ValueENUS = "Default", ValueFRFR = "Par défaut", ValueHRHR = "Zadano", ValueKOKR = "기본값", ValuePLPL = "Domyślny", ValueSLSL = "Privzeto", ValueTRTR = "Varsayılan", ValueZHCN = "默认页", ValueZHTW = "默認頁", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.dashboard.analysis", ValueENUS = "Analysis", ValueFRFR = "Analyse", ValueHRHR = "Analiza", ValueKOKR = "분석", ValuePLPL = "Analityczny", ValueSLSL = "Analiza", ValueTRTR = "Analiz", ValueZHCN = "分析页", ValueZHTW = "分析頁", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.dashboard.monitor", ValueENUS = "Monitor", ValueFRFR = "Moniteur", ValueHRHR = "Monitor", ValueKOKR = "모니터", ValuePLPL = "Monitorowanie", ValueSLSL = "Monitor", ValueTRTR = "İzleme", ValueZHCN = "监控页", ValueZHTW = "監控頁", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.dashboard.workplace", ValueENUS = "Workplace", ValueFRFR = "Lieu de travail", ValueHRHR = "Radni prostor", ValueKOKR = "Workplace", ValuePLPL = "Miejsce pracy", ValueSLSL = "Delovno mesto", ValueTRTR = "Çalışma Alanı", ValueZHCN = "工作台", ValueZHTW = "工作臺", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.shortcut", ValueENUS = "Shortcut", ValueFRFR = "Raccourci", ValueHRHR = "Prečica", ValueKOKR = "바로 가기", ValuePLPL = "Skrót", ValueSLSL = "Bližnjica", ValueTRTR = "Kısayol", ValueZHCN = "快捷菜单", ValueZHTW = "快捷菜單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.widgets", ValueENUS = "Widgets", ValueFRFR = "Widgets", ValueHRHR = "Programčić", ValueKOKR = "위젯", ValuePLPL = "Widżety", ValueSLSL = "Pripomočki", ValueTRTR = "Araçlar", ValueZHCN = "小部件", ValueZHTW = "小部件", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.alain", ValueENUS = "Alain", ValueFRFR = "Alain", ValueHRHR = "Alain", ValueKOKR = "Alain", ValuePLPL = "Alain", ValueSLSL = "Alain", ValueTRTR = "Alain", ValueZHCN = "Alain", ValueZHTW = "Alain", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.style", ValueENUS = "Style", ValueFRFR = "Style", ValueHRHR = "Stil", ValueKOKR = "스타일", ValuePLPL = "Styl", ValueSLSL = "Slog", ValueTRTR = "Stil", ValueZHCN = "样式", ValueZHTW = "樣式", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.style.typography", ValueENUS = "Typography", ValueFRFR = "Typographie", ValueHRHR = "Tipografija", ValueKOKR = "타이포그래피", ValuePLPL = "Typografia", ValueSLSL = "Pisava", ValueTRTR = "Tipografi", ValueZHCN = "字体排印", ValueZHTW = "字體排印", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.style.gridmasonry", ValueENUS = "Grid Masonry", ValueFRFR = "Grille de maçonnerie", ValueHRHR = "Mreža", ValueKOKR = "Grid Masonry", ValuePLPL = "Grid Masonry", ValueSLSL = "Mreža", ValueTRTR = "Masonry Izgara", ValueZHCN = "瀑布流", ValueZHTW = "瀑佈流", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.style.colors", ValueENUS = "Colors", ValueFRFR = "Couleurs", ValueHRHR = "Boje", ValueKOKR = "색상", ValuePLPL = "Kolory", ValueSLSL = "Barve", ValueTRTR = "Renkler", ValueZHCN = "色彩", ValueZHTW = "色彩", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.delon", ValueENUS = "Delon Lib", ValueFRFR = "Delon Lib", ValueHRHR = "Delon lib", ValueKOKR = "Delon 라이브러리", ValuePLPL = "Biblioteka Delon", ValueSLSL = "Delon Lib", ValueTRTR = "Delon Kütüphanesi", ValueZHCN = "Delon 类库", ValueZHTW = "Delon 類庫", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.delon.form", ValueENUS = "Dynamic Form", ValueFRFR = "Forme dynamique", ValueHRHR = "Dinamični obrazac", ValueKOKR = "다이나믹폼", ValuePLPL = "Dynamiczne formularze", ValueSLSL = "Dinamični obrazec", ValueTRTR = "Dinamik Form", ValueZHCN = "动态表单", ValueZHTW = "動態錶單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.delon.table", ValueENUS = "Simple table", ValueFRFR = "Tableau simple", ValueHRHR = "Jednostavna tablica", ValueKOKR = "심플테이블", ValuePLPL = "Prosta tabela", ValueSLSL = "Enostavna tabela", ValueTRTR = "Basit Tablo", ValueZHCN = "简易表格", ValueZHTW = "簡易錶格", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.delon.util", ValueENUS = "Util", ValueFRFR = "Util", ValueHRHR = "Alati", ValueKOKR = "유틸", ValuePLPL = "Narzędzia", ValueSLSL = "Pomoč", ValueTRTR = "Faydalı", ValueZHCN = "工具集", ValueZHTW = "工具集", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.dev.paratp.copy", ValueENUS = "copy", ValueFRFR = "Copier", ValueHRHR = "", ValueKOKR = "복제 하 다.", ValuePLPL = "kopiuj", ValueSLSL = "kopija", ValueTRTR = "", ValueZHCN = "复制", ValueZHTW = "複製", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "button.new", ValueENUS = "new", ValueFRFR = "Nouveau", ValueHRHR = "", ValueKOKR = "신.", ValuePLPL = "nowe", ValueSLSL = "novo", ValueTRTR = "", ValueZHCN = "新建", ValueZHTW = "新建", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.delon.print", ValueENUS = "Print", ValueFRFR = "Imprimer", ValueHRHR = "Ispis", ValueKOKR = "출력", ValuePLPL = "Drukowanie", ValueSLSL = "Natisni", ValueTRTR = "Çıktı", ValueZHCN = "打印", ValueZHTW = "列印", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.delon.guard", ValueENUS = "Route Guard", ValueFRFR = "Route Guard", ValueHRHR = "Stražar rute", ValueKOKR = "라우팅 가드", ValuePLPL = "Route Guard", ValueSLSL = "Route Guard", ValueTRTR = "Route Guard", ValueZHCN = "路由守卫", ValueZHTW = "路由守衛", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.delon.cache", ValueENUS = "Cache", ValueFRFR = "Cache", ValueHRHR = "Cache", ValueKOKR = "캐쉬", ValuePLPL = "Pamięć podręczna", ValueSLSL = "Začasni pomnilnik", ValueTRTR = "Cache", ValueZHCN = "字典缓存", ValueZHTW = "字典緩存", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.delon.qr", ValueENUS = "QR", ValueFRFR = "QR", ValueHRHR = "QR", ValueKOKR = "QR", ValuePLPL = "QR", ValueSLSL = "QR", ValueTRTR = "QR", ValueZHCN = "二维码", ValueZHTW = "二維碼", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.infomnt", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "资讯管理", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.delon.acl", ValueENUS = "ACL", ValueFRFR = "ACL", ValueHRHR = "ACL", ValueKOKR = "ACL", ValuePLPL = "ACL", ValueSLSL = "ACL", ValueTRTR = "ACL", ValueZHCN = "基于角色访问控制", ValueZHTW = "基於角色訪問控製", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.delon.downfile", ValueENUS = "Download File", ValueFRFR = "Télécharger un fichier", ValueHRHR = "Preuzmi datoteku", ValueKOKR = "다운로드 파일", ValuePLPL = "Pobierz plik", ValueSLSL = "Prenesi datoteko", ValueTRTR = "Dosya İndirme", ValueZHCN = "下载文件", ValueZHTW = "下載文件", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.delon.xlsx", ValueENUS = "Excel", ValueFRFR = "Excel", ValueHRHR = "Excel", ValueKOKR = "엑셀", ValuePLPL = "Excel", ValueSLSL = "Excel", ValueTRTR = "Excel", ValueZHCN = "Excel操作", ValueZHTW = "Excel操作", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.delon.zip", ValueENUS = "Zip", ValueFRFR = "Zip", ValueHRHR = "Zip", ValueKOKR = "Zip", ValuePLPL = "Zip", ValueSLSL = "Zip", ValueTRTR = "Zip", ValueZHCN = "本地解压缩", ValueZHTW = "在地解壓縮", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.pro", ValueENUS = "Antd Pro", ValueFRFR = "Antd Pro", ValueHRHR = "Antd Pro", ValueKOKR = "Antd Pro", ValuePLPL = "Antd Pro", ValueSLSL = "Antd Pro", ValueTRTR = "Antd Pro", ValueZHCN = "Antd Pro", ValueZHTW = "Antd Pro", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.form", ValueENUS = "Form", ValueFRFR = "Formulaire", ValueHRHR = "Obrazac", ValueKOKR = "양식", ValuePLPL = "Formularze", ValueSLSL = "Obrazec", ValueTRTR = "Form", ValueZHCN = "表单页", ValueZHTW = "錶單頁", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.form.basicform", ValueENUS = "Basic Form", ValueFRFR = "Formulaire de base", ValueHRHR = "Osnovni obrazac", ValueKOKR = "기본 양식", ValuePLPL = "Prosty formularz", ValueSLSL = "Osnovni obrazec", ValueTRTR = "Temel Form", ValueZHCN = "基础表单", ValueZHTW = "基礎錶單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.form.stepform", ValueENUS = "Step Form", ValueFRFR = "Formulaire d'étape", ValueHRHR = "Obrazac u koracima", ValueKOKR = "단계별 양식", ValuePLPL = "Formularz krokowy", ValueSLSL = "Obrazec koraka", ValueTRTR = "Step Form", ValueZHCN = "分步表单", ValueZHTW = "分步錶單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.form.stepform.info", ValueENUS = "Step Form(write transfer information)", ValueFRFR = "Formulaire d'étape (écrire les informations de transfert)", ValueHRHR = "Obrazac u koracima (upišite podatke o prijenosu)", ValueKOKR = "단계별 양식(이전 정보 쓰기)", ValuePLPL = "Step Form(Wprowadź informacje dotyczące przelewu)", ValueSLSL = "Obrazec koraka (navedite informacijo za prenos)", ValueTRTR = "Step Form(Transfer bilgisi yazınız)", ValueZHCN = "分步表单（填写转账信息）", ValueZHTW = "分步錶單（填寫轉賬信息）", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.form.stepform.confirm", ValueENUS = "Step Form(confirm transfer information)", ValueFRFR = "Formulaire d'étape (confirmer les informations de transfert)", ValueHRHR = "Obrazac u koracima (potvrdite podatke o prijenosu)", ValueKOKR = "단계별 양식(전송 정보 확인)", ValuePLPL = "Step Form(Potwierdź informacje o przesyłce)", ValueSLSL = "Obrazec koraka (potrdite informacijo za prenos)", ValueTRTR = "Step Form(transfer bilgisini onaylayın)", ValueZHCN = "分步表单（确认转账信息）", ValueZHTW = "分步錶單（確認轉賬信息）", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.form.stepform.result", ValueENUS = "Step Form(finished)", ValueFRFR = "Formulaire d'étape (terminé)", ValueHRHR = "Obrazac u koracima (završeno)", ValueKOKR = "단계별 양식(완료)", ValuePLPL = "Step Form(Zakończone)", ValueSLSL = "Obrazec koraka (končano)", ValueTRTR = "Step Form(tamamlanmış)", ValueZHCN = "分步表单（完成）", ValueZHTW = "分步錶單（完成）", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.form.advancedform", ValueENUS = "Advanced Form", ValueFRFR = "Formulaire avancé", ValueHRHR = "Napredni obrazac", ValueKOKR = "고급 양식", ValuePLPL = "Zaawnsowany formularz", ValueSLSL = "Napredni obrazec", ValueTRTR = "Gelişmiş Form", ValueZHCN = "高级表单", ValueZHTW = "高級錶單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.list", ValueENUS = "List", ValueFRFR = "Liste", ValueHRHR = "Popis", ValueKOKR = "리스트", ValuePLPL = "Listy", ValueSLSL = "Seznam", ValueTRTR = "Liste", ValueZHCN = "列表页", ValueZHTW = "列錶頁", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.list.searchtable", ValueENUS = "Search Table", ValueFRFR = "Rechercher dans la table", ValueHRHR = "Tablica pretraživanja", ValueKOKR = "검색 테이블", ValuePLPL = "Przeszukiwalna tabela", ValueSLSL = "Iskalna tabela", ValueTRTR = "Arama Tablo", ValueZHCN = "查询表格", ValueZHTW = "查詢錶格", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.list.basiclist", ValueENUS = "Basic List", ValueFRFR = "Liste de base", ValueHRHR = "Osnovni popis", ValueKOKR = "리본 리스트", ValuePLPL = "Prosta lista", ValueSLSL = "Osnovni seznam", ValueTRTR = "Basit Liste", ValueZHCN = "标准列表", ValueZHTW = "標準列錶", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.list.cardlist", ValueENUS = "Card List", ValueFRFR = "Liste des cartes", ValueHRHR = "Popis kartica", ValueKOKR = "카드 리스트", ValuePLPL = "Lista kart", ValueSLSL = "Kartični seznam", ValueTRTR = "Kart Listesi", ValueZHCN = "卡片列表", ValueZHTW = "卡片列錶", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.list.searchlist", ValueENUS = "Search List", ValueFRFR = "Liste de recherche", ValueHRHR = "Popis pretraživanja", ValueKOKR = "검색 리스트", ValuePLPL = "Listy przeszukiwalne", ValueSLSL = "Išči po seznamu", ValueTRTR = "Arama Listesi", ValueZHCN = "搜索列表", ValueZHTW = "搜索列錶", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.list.searchlist.articles", ValueENUS = "Search List(articles)", ValueFRFR = "Liste de recherche (articles)", ValueHRHR = "Popis za pretraživanje (članci)", ValueKOKR = "검색 리스트(게시글)", ValuePLPL = "Lista przeszukiwalna(artykuły)", ValueSLSL = "Išči po seznamu (članki)", ValueTRTR = "Arama Listesi(articles)", ValueZHCN = "搜索列表（文章）", ValueZHTW = "搜索列錶（文章）", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.list.searchlist.projects", ValueENUS = "Search List(projects)", ValueFRFR = "Liste de recherche (projets)", ValueHRHR = "Popis za pretraživanje (projekti)", ValueKOKR = "검색 리스트(프로젝트)", ValuePLPL = "Lista przeszukiwalna(projekty)", ValueSLSL = "Išči po seznamu (projekti)", ValueTRTR = "Search List(projects)", ValueZHCN = "搜索列表（项目）", ValueZHTW = "搜索列錶（項目）", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.list.searchlist.applications", ValueENUS = "Search List(applications)", ValueFRFR = "Liste de recherche (applications)", ValueHRHR = "Popis za pretraživanje (aplikacije)", ValueKOKR = "검색 리스트(어플리케이션)", ValuePLPL = "Lista przeszukiwalna(aplikacje)", ValueSLSL = "Išči po seznamu (aplikacije)", ValueTRTR = "Search List(applications)", ValueZHCN = "搜索列表（应用）", ValueZHTW = "搜索列錶（應用）", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.profile", ValueENUS = "Profile", ValueFRFR = "Profil", ValueHRHR = "Profil", ValueKOKR = "프로필", ValuePLPL = "Profil", ValueSLSL = "Profil", ValueTRTR = "Profil", ValueZHCN = "详情页", ValueZHTW = "詳情頁", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.profile.basic", ValueENUS = "Basic Profile", ValueFRFR = "Profil de base", ValueHRHR = "Osnovni profil", ValueKOKR = "기본 프로필", ValuePLPL = "Prosty profil", ValueSLSL = "Osnovni profil", ValueTRTR = "Temel Profil", ValueZHCN = "基础详情页", ValueZHTW = "基礎詳情頁", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.profile.advanced", ValueENUS = "Advanced Profile", ValueFRFR = "Profil avancé", ValueHRHR = "Napredni profil", ValueKOKR = "고급 프로필", ValuePLPL = "Zaawansowany profil", ValueSLSL = "Napredni profil", ValueTRTR = "Gelişmiş Profil", ValueZHCN = "高级详情页", ValueZHTW = "高級詳情頁", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.result", ValueENUS = "Result", ValueFRFR = "Résultat", ValueHRHR = "Rezultat", ValueKOKR = "결과", ValuePLPL = "Wyniki", ValueSLSL = "Rezultat", ValueTRTR = "Sonuç", ValueZHCN = "结果页", ValueZHTW = "結果頁", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.result.success", ValueENUS = "Success", ValueFRFR = "Succès", ValueHRHR = "Uspjeh", ValueKOKR = "성공", ValuePLPL = "Sukces", ValueSLSL = "Uspešno", ValueTRTR = "Başarılı", ValueZHCN = "成功页", ValueZHTW = "成功頁", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.result.fail", ValueENUS = "Fail", ValueFRFR = "Échec", ValueHRHR = "Nauspjeh", ValueKOKR = "실패", ValuePLPL = "Porażka", ValueSLSL = "Neuspešno", ValueTRTR = "Başarısız", ValueZHCN = "失败页", ValueZHTW = "失敗頁", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.exception", ValueENUS = "Exception", ValueFRFR = "Exception", ValueHRHR = "Iznimka", ValueKOKR = "예외", ValuePLPL = "Błąd", ValueSLSL = "Izjema", ValueTRTR = "İstisna", ValueZHCN = "异常页", ValueZHTW = "異常頁", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.exception.not-permission", ValueENUS = "403", ValueFRFR = "403", ValueHRHR = "403", ValueKOKR = "403", ValuePLPL = "403", ValueSLSL = "403", ValueTRTR = "403", ValueZHCN = "403", ValueZHTW = "403", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.exception.not-find", ValueENUS = "404", ValueFRFR = "404", ValueHRHR = "404", ValueKOKR = "404", ValuePLPL = "404", ValueSLSL = "404", ValueTRTR = "404", ValueZHCN = "404", ValueZHTW = "404", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.exception.server-error", ValueENUS = "500", ValueFRFR = "500", ValueHRHR = "500", ValueKOKR = "500", ValuePLPL = "500", ValueSLSL = "500", ValueTRTR = "500", ValueZHCN = "500", ValueZHTW = "500", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.account", ValueENUS = "Account", ValueFRFR = "Compte", ValueHRHR = "Račun", ValueKOKR = "계정", ValuePLPL = "Konto", ValueSLSL = "Račun", ValueTRTR = "Hesap", ValueZHCN = "个人页", ValueZHTW = "個人頁", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.account.center", ValueENUS = "Account Center", ValueFRFR = "Centre de comptes", ValueHRHR = "Upravljanje računima", ValueKOKR = "계정 센터", ValuePLPL = "Centrum konta", ValueSLSL = "Središče za račun", ValueTRTR = "Hesap Center", ValueZHCN = "个人中心", ValueZHTW = "個人中心", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.account.settings", ValueENUS = "Account Settings", ValueFRFR = "Paramètres du compte", ValueHRHR = "Postavke računa", ValueKOKR = "계정 설정", ValuePLPL = "Ustawienia konta", ValueSLSL = "Nastavitve računa", ValueTRTR = "Hesap Ayarları", ValueZHCN = "个人设置", ValueZHTW = "個人設置", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.account.trigger", ValueENUS = "Trigger Error", ValueFRFR = "Déclenchement des erreurs", ValueHRHR = "Pozovi grešku", ValueKOKR = "트리거 에러", ValuePLPL = "Błąd wyzwalacza", ValueSLSL = "Napaka sprožilca", ValueTRTR = "Tetikleyici Hatası", ValueZHCN = "触发错误", ValueZHTW = "觸發錯誤", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.account.logout", ValueENUS = "Logout", ValueFRFR = "Déconnexion", ValueHRHR = "Odjava", ValueKOKR = "로그아웃", ValuePLPL = "Wyloguj", ValueSLSL = "Odjava", ValueTRTR = "Çıkış Yap", ValueZHCN = "退出登录", ValueZHTW = "退出登錄", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.more", ValueENUS = "More", ValueFRFR = "Plus", ValueHRHR = "Više", ValueKOKR = "더 보기", ValuePLPL = "Więcej", ValueSLSL = "Več", ValueTRTR = "Daha", ValueZHCN = "更多", ValueZHTW = "更多", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.report", ValueENUS = "Report", ValueFRFR = "Rapport", ValueHRHR = "Izvješće", ValueKOKR = "보고서", ValuePLPL = "Raport", ValueSLSL = "Poročilo", ValueTRTR = "Rapor", ValueZHCN = "报表", ValueZHTW = "報錶", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.report.relation", ValueENUS = "Relation Map", ValueFRFR = "Carte des relations", ValueHRHR = "Karta relacija", ValueKOKR = "연관 맵", ValuePLPL = "Relation Map", ValueSLSL = "Zemljevid relacije", ValueTRTR = "İlişki Haritası", ValueZHCN = "全屏关系图", ValueZHTW = "全屏關係圖", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.extras", ValueENUS = "Extra", ValueFRFR = "Extra", ValueHRHR = "Dodatno", ValueKOKR = "확장", ValuePLPL = "Ekstra", ValueSLSL = "Dodatek", ValueTRTR = "Ekstra", ValueZHCN = "扩展", ValueZHTW = "擴展", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.extras.helpcenter", ValueENUS = "Help Center", ValueFRFR = "Centre d'aide", ValueHRHR = "Centar za pomoć", ValueKOKR = "도움말 센터", ValuePLPL = "Centrum pomocy", ValueSLSL = "Središče za pomoč", ValueTRTR = "Yardım Merkezi", ValueZHCN = "帮助中心", ValueZHTW = "幫助中心", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.extras.settings", ValueENUS = "Settings", ValueFRFR = "Paramètres", ValueHRHR = "Postavke", ValueKOKR = "설정", ValuePLPL = "Ustawienia", ValueSLSL = "Nastavitve", ValueTRTR = "Ayarlar", ValueZHCN = "设置", ValueZHTW = "設置", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.extras.poi", ValueENUS = "Poi", ValueFRFR = "Poi", ValueHRHR = "Poi", ValueKOKR = "POI", ValuePLPL = "POI", ValueSLSL = "Poi", ValueTRTR = "Poi", ValueZHCN = "门店", ValueZHTW = "門店", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.register.sign-in", ValueENUS = "Already have an account?", ValueFRFR = "Vous avez déjà un compte?", ValueHRHR = "Već imate račun?", ValueKOKR = "기존 계정으로 로그인", ValuePLPL = "Już masz konto?", ValueSLSL = "Že imate račun?", ValueTRTR = "Hesabınız zaten var ı?", ValueZHCN = "使用已有账户登录", ValueZHTW = "使用已有賬戶登錄", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.test", ValueENUS = "Gongzhuan No.{{no}} shop", ValueFRFR = "Gongzhuan No. {{no}} shop", ValueHRHR = "Gongzhuan br. {{No}} trgovina", ValueKOKR = "공전로 {{no}}번째 가게", ValuePLPL = "Sklep przy Gongzhuan No.{{no}}", ValueSLSL = "Gongzhuan No.{{no}} shop", ValueTRTR = "Gongzhuan No.{{no}} shop", ValueZHCN = "工专路 {{no}} 号店", ValueZHTW = "工專路 {{no}} 號店", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.introduce", ValueENUS = "Introduce", ValueFRFR = "Introduire", ValueHRHR = "Predstavljanje", ValueKOKR = "지표설명", ValuePLPL = "Wprowadzenie", ValueSLSL = "Predstavitev", ValueTRTR = "Tanıtım", ValueZHCN = "指标说明", ValueZHTW = "指標說明", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.total-sales", ValueENUS = "Total Sales", ValueFRFR = "Ventes totales", ValueHRHR = "Totalna rasprodaja", ValueKOKR = "총 판매", ValuePLPL = "Sprzedaż ogółem", ValueSLSL = "Prodaja skupaj", ValueTRTR = "Toplam Satışlar", ValueZHCN = "总销售额", ValueZHTW = "總銷售額", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.day-sales", ValueENUS = "Day Sales", ValueFRFR = "Ventes du jour", ValueHRHR = "Dnevna prodaja", ValueKOKR = "일일 판매", ValuePLPL = "Dzienna sprzedaż", ValueSLSL = "Prodaja dnevna", ValueTRTR = "Günlük Satışlar", ValueZHCN = "日销售额", ValueZHTW = "日銷售額", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.visits", ValueENUS = "Visits", ValueFRFR = "Visites", ValueHRHR = "Posjeta", ValueKOKR = "방문수", ValuePLPL = "Odwiedzin", ValueSLSL = "Obiski", ValueTRTR = "Zirayetçiler", ValueZHCN = "访问量", ValueZHTW = "訪問量", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.visits-trend", ValueENUS = "Visits Trend", ValueFRFR = "Tendance des visites", ValueHRHR = "Trend posjeta", ValueKOKR = "방문자 트랜드", ValuePLPL = "Trend odwiedzin", ValueSLSL = "Trend obiskov", ValueTRTR = "Ziyaretçi Trendi", ValueZHCN = "访问量趋势", ValueZHTW = "訪問量趨勢", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.visits-ranking", ValueENUS = "Visits Ranking", ValueFRFR = "Classement des visites", ValueHRHR = "Rangiranje posjeta", ValueKOKR = "방문자 랭킹", ValuePLPL = "Ranking odwiedzin", ValueSLSL = "Rangiranje obiskov", ValueTRTR = "Ziyaretçi Sıralaması", ValueZHCN = "门店访问量排名", ValueZHTW = "門店訪問量排名", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.day-visits", ValueENUS = "Day Visits", ValueFRFR = "", ValueHRHR = "Dnevne posjete", ValueKOKR = "일일 방문수", ValuePLPL = "Dziennych odwiedzin", ValueSLSL = "Dnevni obiski", ValueTRTR = "Günlük Ziyaretler", ValueZHCN = "日访问量", ValueZHTW = "日訪問量", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.week", ValueENUS = "Week Ratio", ValueFRFR = "Ratio hebdomadaire", ValueHRHR = "Omjer tjedna", ValueKOKR = "주간", ValuePLPL = "Współczynnik tygodniowy", ValueSLSL = "Tedensko razmerje", ValueTRTR = "Hafta Oranı", ValueZHCN = "周同比", ValueZHTW = "周同比", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.day", ValueENUS = "Day Ratio", ValueFRFR = "Ratio journalier", ValueHRHR = "Dnevni omjer", ValueKOKR = "일간", ValuePLPL = "Współczynnik dzienny", ValueSLSL = "Dnevno razmerje", ValueTRTR = "Günlük Oran", ValueZHCN = "日同比", ValueZHTW = "日同比", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.payments", ValueENUS = "Payments", ValueFRFR = "Paiements", ValueHRHR = "Plaćanja", ValueKOKR = "지불", ValuePLPL = "Płatności", ValueSLSL = "Plačila", ValueTRTR = "Ödemeler", ValueZHCN = "支付笔数", ValueZHTW = "支付筆數", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.conversion-rate", ValueENUS = "Conversion Rate", ValueFRFR = "Taux de conversion", ValueHRHR = "Stopa", ValueKOKR = "전환율", ValuePLPL = "Stopień konwersji", ValueSLSL = "Menjalni tečaj", ValueTRTR = "Dönüştüme Oranı", ValueZHCN = "转化率", ValueZHTW = "轉化率", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.operational-effect", ValueENUS = "Operational Effect", ValueFRFR = "Operational Effect", ValueHRHR = "Operativni učinak", ValueKOKR = "운영 활동 효과", ValuePLPL = "Efekt operacyjny", ValueSLSL = "Operativni učinek", ValueTRTR = "Operational Effect", ValueZHCN = "运营活动效果", ValueZHTW = "運營活動效果", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.sales-trend", ValueENUS = "Stores Sales Trend", ValueFRFR = "Tendance des ventes des magasins", ValueHRHR = "Trendova prodaje", ValueKOKR = "판매 추세", ValuePLPL = "Trend sprzedaży w sklepach", ValueSLSL = "Trend prodaje", ValueTRTR = "Mağaza Satış Trendleri", ValueZHCN = "销售趋势", ValueZHTW = "銷售趨勢", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.sales-ranking", ValueENUS = "Sales Ranking", ValueFRFR = "Classement des ventes", ValueHRHR = "Poredak", ValueKOKR = "판매 랭킹", ValuePLPL = "Ranking sprzedaży", ValueSLSL = "Rangiranje prodaje", ValueTRTR = "Satış Sıralaması", ValueZHCN = "门店销售额排名", ValueZHTW = "門店銷售額排名", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.all-year", ValueENUS = "All Year", ValueFRFR = "Toute l'année", ValueHRHR = "Cijela godina,", ValueKOKR = "올해", ValuePLPL = "Cały rok", ValueSLSL = "Celotno leto", ValueTRTR = "Tüm Yıl", ValueZHCN = "全年", ValueZHTW = "全年", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.all-month", ValueENUS = "All Month", ValueFRFR = "Tout le mois", ValueHRHR = "Cijeli mjesec", ValueKOKR = "이번달", ValuePLPL = "Cały miesiąc", ValueSLSL = "Cel mesec", ValueTRTR = "Tüm Ay", ValueZHCN = "本月", ValueZHTW = "本月", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.all-week", ValueENUS = "All Week", ValueFRFR = "Toute la semaine", ValueHRHR = "Cijeli tjedan", ValueKOKR = "이번주", ValuePLPL = "Cały tydzień", ValueSLSL = "Cel teden", ValueTRTR = "Tüm Hafta", ValueZHCN = "本周", ValueZHTW = "本周", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.all-day", ValueENUS = "All day", ValueFRFR = "Toute la journée", ValueHRHR = "Cijeli dan", ValueKOKR = "오늘", ValuePLPL = "Cały dzień", ValueSLSL = "Cel dan", ValueTRTR = "Tüm Gün", ValueZHCN = "今日", ValueZHTW = "今日", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.search-users", ValueENUS = "Search Users", ValueFRFR = "Rechercher des utilisateurs", ValueHRHR = "Pretraživanje korisnika", ValueKOKR = "검색 사용자", ValuePLPL = "Wyszukających użytkowników", ValueSLSL = "Išči uporabnike", ValueTRTR = "Kullanıcıları ara", ValueZHCN = "搜索用户数", ValueZHTW = "搜索用戶數", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.themecolor.geekblue", ValueENUS = "Geek Glue", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "极客蓝", ValueZHTW = "極客藍", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.per-capita-search", ValueENUS = "Per Capita Search", ValueFRFR = "Recherche par capital", ValueHRHR = "Pretraživanje po osobi", ValueKOKR = "1인당 검색", ValuePLPL = "Wyszukiwań per użytkownik", ValueSLSL = "Iskanje na prebivalca", ValueTRTR = "Kişi bazlı arama", ValueZHCN = "人均搜索次数", ValueZHTW = "人均搜索次數", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.online-top-search", ValueENUS = "Online Top Search", ValueFRFR = "Top des recherche  en ligne", ValueHRHR = "Internetska top pretraga", ValueKOKR = "온라인 인기 검색", ValuePLPL = "Najpopularniejsze wyszukiwania online", ValueSLSL = "Spletno iskanje", ValueTRTR = "En İyi Çevrimiçi arama", ValueZHCN = "线上热门搜索", ValueZHTW = "線上熱門搜索", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.fixedheader", ValueENUS = "Fixed Header", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "固定 Header", ValueZHTW = "固定 Header", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.the-proportion-of-sales", ValueENUS = "The Proportion Of Sales", ValueFRFR = "The Proportion Of Sales", ValueHRHR = "Omjer prodaje", ValueKOKR = "판매 비율", ValuePLPL = "Proporcje sprzedaży", ValueSLSL = "Delež prodaje", ValueTRTR = "Satışların oranı", ValueZHCN = "销售额类别占比", ValueZHTW = "銷售額類別佔比", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.channel.all", ValueENUS = "ALL", ValueFRFR = "TOUS", ValueHRHR = "SVI", ValueKOKR = "모두", ValuePLPL = "WSZYSTKIE", ValueSLSL = "VSE", ValueTRTR = "Herşey", ValueZHCN = "全部渠道", ValueZHTW = "全部通路", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.channel.online", ValueENUS = "Online", ValueFRFR = "En ligne", ValueHRHR = "Aktivni", ValueKOKR = "온라인", ValuePLPL = "Online", ValueSLSL = "Splet", ValueTRTR = "Çevrimiçi", ValueZHCN = "线上", ValueZHTW = "線上", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.channel.stores", ValueENUS = "Stores", ValueFRFR = "Magasins", ValueHRHR = "Trgovine", ValueKOKR = "상점", ValuePLPL = "Sklepy", ValueSLSL = "Trgovine", ValueTRTR = "Mağazalar", ValueZHCN = "门店", ValueZHTW = "門店", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.sales", ValueENUS = "Sales", ValueFRFR = "Ventes", ValueHRHR = "Prodaja", ValueKOKR = "판매", ValuePLPL = "Sprzedaż", ValueSLSL = "Prodaja", ValueTRTR = "Satış", ValueZHCN = "销售额", ValueZHTW = "銷售額", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.traffic", ValueENUS = "Traffic", ValueFRFR = "Trafic", ValueHRHR = "Promet", ValueKOKR = "트래픽", ValuePLPL = "Ruch", ValueSLSL = "Promet", ValueTRTR = "Trafik", ValueZHCN = "客流量", ValueZHTW = "客流量", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.table.rank", ValueENUS = "Rank", ValueFRFR = "Rang", ValueHRHR = "Rang", ValueKOKR = "랭킹", ValuePLPL = "Ranking", ValueSLSL = "Razvrstitev", ValueTRTR = "Oran", ValueZHCN = "排名", ValueZHTW = "排名", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.table.search-keyword", ValueENUS = "Keyword", ValueFRFR = "mot clé", ValueHRHR = "Ključna riječ", ValueKOKR = "키워드", ValuePLPL = "Słowo kluczowe", ValueSLSL = "Ključna beseda", ValueTRTR = "Anahtar Kelime", ValueZHCN = "搜索关键词", ValueZHTW = "搜索關鍵詞", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.table.users", ValueENUS = "Users", ValueFRFR = "Utilisateurs", ValueHRHR = "Korisnici", ValueKOKR = "사용자수", ValuePLPL = "Użytkownicy", ValueSLSL = "Uporabniki", ValueTRTR = "Kullanıcılar", ValueZHCN = "用户数", ValueZHTW = "用戶數", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.analysis.table.weekly-range", ValueENUS = "Weekly Range", ValueFRFR = "Plage hebdomadaire", ValueHRHR = "Tjedno", ValueKOKR = "주간 범위", ValuePLPL = "Zakres tygodniowy", ValueSLSL = "Tedenski razpon", ValueTRTR = "Haftalık Aralık", ValueZHCN = "周涨幅", ValueZHTW = "周漲幅", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.monitor.trading-activity", ValueENUS = "Real-Time Trading Activity", ValueFRFR = "Activité de trading en temps réel", ValueHRHR = "Aktivnost u realnom vremenu", ValueKOKR = "실시간 거래 활동", ValuePLPL = "Aktywność handlowa w czasie rzeczywistym", ValueSLSL = "Analiza trgovanja v realnem času", ValueTRTR = "Gerçek Zamanlı İşlem Etkinliği", ValueZHCN = "活动实时交易情况", ValueZHTW = "活動實時交易情況", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.monitor.total-transactions", ValueENUS = "Total transactions today", ValueFRFR = "Total des transactions aujourd'hui", ValueHRHR = "Ukupno transakcija danas", ValueKOKR = "오늘 총 거래액", ValuePLPL = "Łączna liczba transakcji dzisiaj", ValueSLSL = "Skupno število transakcij danes", ValueTRTR = "Bügünlük toplam işlem", ValueZHCN = "今日交易总额", ValueZHTW = "今日交易總額", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.monitor.sales-target", ValueENUS = "Sales target completion rate", ValueFRFR = "Taux d'achèvement de l'objectif de vente", ValueHRHR = "Ciljna stopa prodaje", ValueKOKR = "판매 목표 완료율", ValuePLPL = "Wskaźnik realizacji celu sprzedaży", ValueSLSL = "Doseganje prodajnega plana", ValueTRTR = "Satış hedeflerini tamamlama oranı", ValueZHCN = "销售目标完成率", ValueZHTW = "銷售目標完成率", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.monitor.remaining-time", ValueENUS = "Remaining time of activity", ValueFRFR = "Temps d'activité restant", ValueHRHR = "Preostalo vrijeme aktivnosti", ValueKOKR = "남은 활동 시간", ValuePLPL = "Pozostały czas aktywności", ValueSLSL = "Preostali čas aktivnosti", ValueTRTR = "Kalan etkinlik süresi", ValueZHCN = "活动剩余时间", ValueZHTW = "活動剩餘時間", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "common.add", ValueENUS = "Add", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "添加", ValueZHTW = "添加", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "common.edit", ValueENUS = "Edit", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "编辑", ValueZHTW = "編輯", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.monitor.total-transactions-per-second", ValueENUS = "Total transactions per second", ValueFRFR = "Total des transactions par seconde", ValueHRHR = "Ukupno transakcija u sekundi", ValueKOKR = "초당 총 트랜잭션", ValuePLPL = "Całkowita liczba transakcji na sekundę", ValueSLSL = "Skupaj transakcij na sekundo", ValueTRTR = "Total transactions per second", ValueZHCN = "每秒交易总额", ValueZHTW = "每秒交易總額", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.monitor.activity-forecast", ValueENUS = "Activity forecast", ValueFRFR = "Prévisions d'activité", ValueHRHR = "Prognoza aktivnosti", ValueKOKR = "활동 예측", ValuePLPL = "Prognoza aktywności", ValueSLSL = "Napoved aktivnosti", ValueTRTR = "Saniye başına toplam işlem", ValueZHCN = "活动情况预测", ValueZHTW = "活動情況預測", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.monitor.efficiency", ValueENUS = "Efficiency", ValueFRFR = "Efficacité", ValueHRHR = "Učinkovitost", ValueKOKR = "능률", ValuePLPL = "Wydajność", ValueSLSL = "Učinkovitost", ValueTRTR = "Verim", ValueZHCN = "券核效率", ValueZHTW = "券核效率", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.monitor.ratio", ValueENUS = "Ratio", ValueFRFR = "Ratio", ValueHRHR = "Omjer", ValueKOKR = "비율", ValuePLPL = "Współczynnik", ValueSLSL = "Razmerje", ValueTRTR = "Oran", ValueZHCN = "跳出率", ValueZHTW = "跳出率", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.monitor.proportion-per-category", ValueENUS = "Proportion Per Category", ValueFRFR = "Proportion Per Category", ValueHRHR = "Proporcija po kategoriji", ValueKOKR = "카테고리별 비율", ValuePLPL = "Proporcje według kategorii", ValueSLSL = "Razmerje na kategorijo", ValueTRTR = "Kategori başına oran", ValueZHCN = "各品类占比", ValueZHTW = "各品類佔比", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.monitor.fast-food", ValueENUS = "Fast food", ValueFRFR = "Restauration rapide", ValueHRHR = "Brza hrana", ValueKOKR = "패스트 푸드", ValuePLPL = "Fast food", ValueSLSL = "Hitre hrana", ValueTRTR = "Fast food", ValueZHCN = "中式快餐", ValueZHTW = "中式快餐", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.monitor.western-food", ValueENUS = "Western food", ValueFRFR = "Cuisine occidentale", ValueHRHR = "Zapadnjačka hrana", ValueKOKR = "서양식", ValuePLPL = "Zachodnia kuchnia", ValueSLSL = "Zahodnjaška hrana", ValueTRTR = "Betı yemeği", ValueZHCN = "西餐", ValueZHTW = "西餐", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.monitor.hot-pot", ValueENUS = "Hot pot", ValueFRFR = "Hot pot", ValueHRHR = "Vrući lonac", ValueKOKR = "냄비", ValuePLPL = "Hot pot", ValueSLSL = "Vroč lonec", ValueTRTR = "Güveç", ValueZHCN = "火锅", ValueZHTW = "火鍋", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.monitor.waiting-for-implementation", ValueENUS = "Waiting for implementation", ValueFRFR = "En attente de mise en œuvre", ValueHRHR = "Čekanje na implementaciju", ValueKOKR = "구현 대기 중", ValuePLPL = "Oczekuje na implementację", ValueSLSL = "Čaka na izvedbo", ValueTRTR = "Uygulama bekleniyor", ValueZHCN = "等待后期实现", ValueZHTW = "Waiting for implementation", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.monitor.popular-searches", ValueENUS = "Popular Searches", ValueFRFR = "", ValueHRHR = "Popularna pretraživanja", ValueKOKR = "인기 검색", ValuePLPL = "Popularne wyszukiwania", ValueSLSL = "Priljubljena iskanja", ValueTRTR = "Popüler Aramalar", ValueZHCN = "热门搜索", ValueZHTW = "熱門搜索", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.monitor.resource-surplus", ValueENUS = "Resource Surplus", ValueFRFR = "Surplus de ressources", ValueHRHR = "Višak resursa", ValueKOKR = "자원 여분", ValuePLPL = "Nadwyżka zasobów", ValueSLSL = "Presežek virov", ValueTRTR = "Kaynak Fazlası", ValueZHCN = "资源剩余", ValueZHTW = "資源剩餘", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.monitor.fund-surplus", ValueENUS = "Fund Surplus", ValueFRFR = "Excédent de fonds", ValueHRHR = "Prekomjerni fond", ValueKOKR = "보조금 기금 흑자", ValuePLPL = "Nadwyżka funduszu", ValueSLSL = "Presežek sredstev", ValueTRTR = "Fon Fazlası", ValueZHCN = "补贴资金剩余", ValueZHTW = "補貼資金剩餘", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.lock", ValueENUS = "Lock", ValueFRFR = "Verrouiller", ValueHRHR = "Zaključaj", ValueKOKR = "잠금", ValuePLPL = "Zablokuj", ValueSLSL = "Zakleni", ValueTRTR = "Kilitli", ValueZHCN = "锁屏", ValueZHTW = "鎖屏", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.themecolor.purple", ValueENUS = "Golden Purple", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "酱紫", ValueZHTW = "醬紫", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.login.message-invalid-credentials", ValueENUS = "Invalid username or password（admin/ant.design）", ValueFRFR = "Nom d'utilisateur ou mot de passe invalide （admin / ant.design）", ValueHRHR = "Nevažeće korisničko ime ili lozinka ", ValueKOKR = "사용자 정보 또는 패스워드가 유효하지 않습니다.（admin/ant.design）", ValuePLPL = "Nieprawidłowa nazwa użytkownika lub hasło（admin/ant.design）", ValueSLSL = "Nnapačno uporabniško ime ali geslo", ValueTRTR = "Kullanıcı adı veya şifre geçersizdir（admin/ant.design）", ValueZHCN = "账户或密码错误（admin/ant.design）", ValueZHTW = "賬戶或密碼錯誤（admin/ant.design）", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.login.message-invalid-verification-code", ValueENUS = "Invalid verification code", ValueFRFR = "Code de vérification non valide", ValueHRHR = "Nevažeći kontrolni kôd", ValueKOKR = "인증 코드가 잘못되었습니다.", ValuePLPL = "Nieprawidłowy kod weryfikacyjny", ValueSLSL = "Napačna verifikacijska koda", ValueTRTR = "Doğrulama kodu geçersizdir", ValueZHCN = "验证码错误", ValueZHTW = "驗證碼錯誤", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.login.tab-login-credentials", ValueENUS = "Credentials", ValueFRFR = "Identifiants", ValueHRHR = "Vjerodajnice", ValueKOKR = "계정 패스워드 로그인", ValuePLPL = "Uprawnienia", ValueSLSL = "Začetnice", ValueTRTR = "Kimlik bilgileri", ValueZHCN = "账户密码登录", ValueZHTW = "賬戶密碼登錄", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.login.tab-login-mobile", ValueENUS = "Mobile number", ValueFRFR = "Numéro de portable", ValueHRHR = "Broj mobitela", ValueKOKR = "모바일 번호 로그인", ValuePLPL = "Numer telefonu komórkowego", ValueSLSL = "Mobilna številka", ValueTRTR = "Telefon numarası", ValueZHCN = "手机号登录", ValueZHTW = "手機號登錄", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.login.remember-me", ValueENUS = "Remember me", ValueFRFR = "Se souvenir de moi", ValueHRHR = "Zapamti me", ValueKOKR = "자동 로그인", ValuePLPL = "Zapamiętaj mnie", ValueSLSL = "Opomni me", ValueTRTR = "Beni hatırla", ValueZHCN = "自动登录", ValueZHTW = "自動登錄", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.login.forgot-password", ValueENUS = "Forgot your password?", ValueFRFR = "Mot de passe oublié?", ValueHRHR = "Zaboravili ste zaporku?", ValueKOKR = "비밀번호를 잊어 버렸습니까?", ValuePLPL = "Zapomniałeś hasła?", ValueSLSL = "Pozabljeno geslo?", ValueTRTR = "Parolanızı mı unuttunuz?", ValueZHCN = "忘记密码", ValueZHTW = "忘記密碼", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.login.sign-in-with", ValueENUS = "Sign in with", ValueFRFR = "Connectez-vous avec", ValueHRHR = "Prijava sa", ValueKOKR = "다른 방법으로 로그인", ValuePLPL = "Zaloguj się za pomocą", ValueSLSL = "Prijavi se kot", ValueTRTR = "Şununla giriş yapın", ValueZHCN = "其他登录方式", ValueZHTW = "其他登錄方式", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.login.signup", ValueENUS = "Sign up", ValueFRFR = "Inscription", ValueHRHR = "Registracija", ValueKOKR = "가입", ValuePLPL = "Zarejestruj się", ValueSLSL = "Registracija", ValueTRTR = "Kaydol", ValueZHCN = "注册账户", ValueZHTW = "註冊賬戶", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.login.login", ValueENUS = "Login", ValueFRFR = "Connexion", ValueHRHR = "Prijava", ValueKOKR = "로그인", ValuePLPL = "Logowanie", ValueSLSL = "Prijava", ValueTRTR = "Giriş", ValueZHCN = "登录", ValueZHTW = "登錄", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.register.register", ValueENUS = "Register", ValueFRFR = "S'inscrire", ValueHRHR = "Registracija", ValueKOKR = "등록", ValuePLPL = "Rejestracja", ValueSLSL = "Prijavi se", ValueTRTR = "Kayıt", ValueZHCN = "注册", ValueZHTW = "註冊", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.register.get-verification-code", ValueENUS = "Get code", ValueFRFR = "Obtenir le code", ValueHRHR = "Dohvati kôd", ValueKOKR = "인증코드 받기", ValuePLPL = "Pobierz kod", ValueSLSL = "Pridobi kodo", ValueTRTR = "Kodu al", ValueZHCN = "获取验证码", ValueZHTW = "獲取驗證碼", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.sys.permission.list", ValueENUS = "Permission List", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "权限列表", ValueZHTW = "權限列錶", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.register-result.msg", ValueENUS = "Account：registered at {{email}}", ValueFRFR = "Compte ： inscrit avec {{email}}", ValueHRHR = "Račun registriran na {{email}}", ValueKOKR = "{{email}} 으로 계정이 등록 되었습니다.", ValuePLPL = "Konto：zarejstrowane dla {{email}}", ValueSLSL = "Račun ： registriran na {{email}}", ValueTRTR = "Hesap：{{email}} kayıtlı", ValueZHCN = "你的账户：{{email}} 注册成功", ValueZHTW = "妳的賬戶：{{email}} 註冊成功", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.goal.required", ValueENUS = "Please enter a description of the goal", ValueFRFR = "Veuillez saisir une description de l'objectif", ValueHRHR = "Unesite opis cilja", ValueKOKR = "목표에 대한 설명을 입력하십시오.", ValuePLPL = "Proszę podać opis dla tego celu", ValueSLSL = "Vnesite opis cilja", ValueTRTR = "Lütfen hedef için bir açıklama giriniz", ValueZHCN = "请输入目标描述", ValueZHTW = "請輸入目標描述", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.standard.required", ValueENUS = "Please enter a metric", ValueFRFR = "Veuillez saisir une statistique", ValueHRHR = "Unesite mjerni podatak", ValueKOKR = "측정 항목을 입력하십시오.", ValuePLPL = "Proszę wskazać metrykę", ValueSLSL = "Vnesite meritev", ValueTRTR = "Lütfen bir metrik giriniz", ValueZHCN = "请输入衡量标准", ValueZHTW = "請輸入衡量標淮", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "common.list", ValueENUS = "List", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "列表", ValueZHTW = "列錶", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.register-result.activation-email", ValueENUS = "The activation email has been sent to your email address and is valid for 24 hours. Please log in to the email in time and click on the link in the email to activate the account.", ValueFRFR = "L'e-mail d'activation a été envoyé à votre adresse e-mail et est valide pendant 24 heures. Veuillez vous connecter à l'e-mail à temps et cliquer sur le lien dans l'e-mail pour activer le compte.", ValueHRHR = "Poruka za aktivaciju poslana je na vašu adresu epošte i vrijedi 24 sata. Prijavite se na vrijeme i kliknite poveznicu u epošti da biste aktivirali račun.", ValueKOKR = "활성화 이메일은 귀하의 이메일 주소로 발송되었으며 24 시간 동안 유효합니다. 시간내에 해당 이메일에 로그인하고 이메일의 링크를 클릭하여 계정을 활성화하십시오.", ValuePLPL = "Email aktywacyjny został wysłany na wskazany adres i będzie ważny przez 24 godiny. Proszę, sprawdź swoją pocztę w tym czasie i kliknij na link wskazany w wiadomości aby aktywować konto", ValueSLSL = "Aktivacijsko e-poštno sporočilo je bilo poslano na vaš e-poštni naslov in je veljavno 24 ur. Prosimo, da se pravočasno preverite e-pošto in kliknite povezavo v e-poštnem sporočilu, da aktivirate račun.", ValueTRTR = "Aktivasyon e-postası e-posta adresinize gönderilmiştir ve 24 saat geçerlidir. Lütfen e-postaya zamanında giriş yapın ve hesabı etkinleştirmek için e-postadaki bağlantıya tıklayın.", ValueZHCN = "激活邮件已发送到你的邮箱中，邮件有效期为24小时。请及时登录邮箱，点击邮件中的链接激活帐户。", ValueZHTW = "激活郵件已發送到妳的郵箱中，郵件有效期為24小時。請及時登錄郵箱，點擊郵件中的鏈接激活帳戶。", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.register-result.back-home", ValueENUS = "Back to home", ValueFRFR = "Retour à l'accueil", ValueHRHR = "Povratak na naslovnicu", ValueKOKR = "홈으로 가기", ValuePLPL = "Powróć do strony głównej", ValueSLSL = "Nazaj domov", ValueTRTR = "Ana sayfaya dön", ValueZHCN = "返回首页", ValueZHTW = "返回首頁", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.register-result.view-mailbox", ValueENUS = "View mailbox", ValueFRFR = "Afficher la boîte aux lettres", ValueHRHR = "Prikaži pretinac", ValueKOKR = "메일 보기", ValuePLPL = "Zobacz skrzynkę odbiorczą", ValueSLSL = "Poglej nabiralnik", ValueTRTR = "Posta kutusunu görüntüle", ValueZHCN = "查看邮箱", ValueZHTW = "檢視郵箱", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.email.required", ValueENUS = "Please enter your email!", ValueFRFR = "Veuillez entrer votre email!", ValueHRHR = "Unesite svoju e-poštu!", ValueKOKR = "이메일 정보를 입력하세요.", ValuePLPL = "Proszę podać adres email!", ValueSLSL = "Prosim vnesite vaš e-mail", ValueTRTR = "Lütfen e-postanızı giriniz!", ValueZHCN = "请输入邮箱地址！", ValueZHTW = "請輸入郵箱地址！", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.email.wrong-format", ValueENUS = "The email address is in the wrong format!", ValueFRFR = "L'adresse e-mail est au mauvais format!", ValueHRHR = "Adresa e-pošte je u pogrešnom obliku!", ValueKOKR = "올바른 이메일 주소가 아닙니다.", ValuePLPL = "Adres email jest w nieprawidłowym formacie!", ValueSLSL = "e-mail naslov je v napačnem formatu!", ValueTRTR = "E-posta adresı formatı yanlıştır!", ValueZHCN = "邮箱地址格式错误！", ValueZHTW = "郵箱地址格式錯誤！", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.navigationmode", ValueENUS = "Navigation Mode", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "导航模式", ValueZHTW = "導航模式", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.password.required", ValueENUS = "Please enter your password!", ValueFRFR = "Veuillez entrer votre mot de passe!", ValueHRHR = "Unesite svoju lozinku!", ValueKOKR = "패스워드를 입력하세요", ValuePLPL = "Proszę podać swoje hasło!", ValueSLSL = "Prosim vnesite vaše geslo!", ValueTRTR = "Lütfen şifrenizi giriniz!", ValueZHCN = "请输入密码！", ValueZHTW = "請輸入密碼！", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.fixedsidebar", ValueENUS = "Fixed Sidebar", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "固定侧边菜单", ValueZHTW = "固定側邊菜單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.system.menu", ValueENUS = "Menu", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "菜单", ValueZHTW = "菜單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.password.twice", ValueENUS = "The passwords entered twice do not match!", ValueFRFR = "Les mots de passe saisis deux fois ne correspondent pas!", ValueHRHR = "Unesene zaporke se ne podudaraju!", ValueKOKR = "입력한 패스워드가 2 회 틀렸습니다.", ValuePLPL = "Pierwsze oraz powtórzone hasło nie są identyczne!", ValueSLSL = "Dvakrat vnesena gesla se ne ujemajo!", ValueTRTR = "Şifre doğrulama eşleşmiyor!", ValueZHCN = "两次输入的密码不匹配!", ValueZHTW = "兩次輸入的密碼不匹配!", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.password.strength.msg", ValueENUS = "Please enter at least 6 characters and don't use passwords that are easy to guess.", ValueFRFR = "Veuillez saisir au moins 6 caractères et n'utilisez pas de mots de passe faciles à deviner.", ValueHRHR = "Unesite najmanje 6 znakova i ne koristite lozinke koje je lako pogoditi.", ValueKOKR = "6 자 이상 입력하십시오. 추측하기 쉬운 암호를 사용하지 마십시오.", ValuePLPL = "Hasło powinno być trudne do odgadnięcia oraz składać się z przynajmniej 6 znaków", ValueSLSL = "Vnesite vsaj 6 znakov in ne uporabljajte gesel, ki jih je enostavno uganiti.", ValueTRTR = "Lütfen en az 6 karakter girin ve tahmin edilmesi kolay şifreler kullanmayın.", ValueZHCN = "请至少输入 6 个字符。请不要使用容易被猜到的密码。", ValueZHTW = "請至少輸入 6 個字符。請不要使用容易被猜到的密碼。", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.password.strength.strong", ValueENUS = "Strength: strong", ValueFRFR = "Force: forte", ValueHRHR = "Jaka  ", ValueKOKR = "비밀번호 강도: 강력", ValuePLPL = "Siła: mocne", ValueSLSL = "Jakost: močno", ValueTRTR = "Şifre Karmaşıklığı: Güçlü", ValueZHCN = "强度：强", ValueZHTW = "強度：強", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.password.strength.medium", ValueENUS = "Strength: medium", ValueFRFR = "Force: moyenne", ValueHRHR = "Srednja ", ValueKOKR = "비밀번호 강도: 중간", ValuePLPL = "Siła: średni", ValueSLSL = "Jakost: srednje", ValueTRTR = "Şifre Karmaşıklığı: orta", ValueZHCN = "强度：中", ValueZHTW = "強度：中", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.password.strength.short", ValueENUS = "Strength: too short", ValueFRFR = "Force: trop courte", ValueHRHR = "Slaba  ", ValueKOKR = "비밀번호 강도: 취약", ValuePLPL = "Siła: zbyt krótkie", ValueSLSL = "Jakost: prekratko", ValueTRTR = "Şifre Karmaşıklığı: çok kısa", ValueZHCN = "强度：太短", ValueZHTW = "強度：太短", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.confirm-password.required", ValueENUS = "Please confirm your password!", ValueFRFR = "Veuillez confirmer votre mot de passe!", ValueHRHR = "Potvrdite zaporku!", ValueKOKR = "암호를 확인하세요.", ValuePLPL = "Proszę, potwierdź swoje hasło!", ValueSLSL = "Porsim potrdite vaše geslo!", ValueTRTR = "Lütfen şifrenizi doğrulayınız!", ValueZHCN = "请确认密码！", ValueZHTW = "請確認密碼！", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.phone-number.required", ValueENUS = "Please enter your phone number!", ValueFRFR = "Veuillez entrer votre numéro de téléphone!", ValueHRHR = "Unesite svoj telefonski broj!", ValueKOKR = "전화번호를 입력하세요.", ValuePLPL = "Proszę podać numer telefonu komórkowego!", ValueSLSL = "Prosim vnesite vašo mobilno številko!", ValueTRTR = "Lütfen telefon numaranızı giriniz!", ValueZHCN = "请输入手机号！", ValueZHTW = "請輸入手機號！", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.sys.permission.root", ValueENUS = "Add Root Node", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "添加根节点", ValueZHTW = "添加根節點", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.phone-number.wrong-format", ValueENUS = "Malformed phone number!", ValueFRFR = "Numéro de téléphone incorrect!", ValueHRHR = "Pogrešan telefonski broj!", ValueKOKR = "올바른 전화번호가 아닙니다.", ValuePLPL = "Nieprawidłowy numer telefonu!", ValueSLSL = "Napačna telefonska številka!", ValueTRTR = "Hatalı telefon numarası!", ValueZHCN = "手机号格式错误！", ValueZHTW = "手機號格式錯誤！", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.verification-code.required", ValueENUS = "Please enter the verification code!", ValueFRFR = "Veuillez saisir le code de vérification!", ValueHRHR = "Unesite kontrolni kôd!", ValueKOKR = "인증코드를 입력하세요.", ValuePLPL = "Proszę podać kod weryfikacyjny!", ValueSLSL = "Vnesite kodo za preverjanje", ValueTRTR = "Lütfen doğrulama kodunu giriniz!", ValueZHCN = "请输入验证码！", ValueZHTW = "請輸入驗證碼！", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.title.required", ValueENUS = "Please enter a title", ValueFRFR = "Veuillez saisir un titre", ValueHRHR = "Unesite naslov", ValueKOKR = "제목을 입력하세요.", ValuePLPL = "Proszę podać tytuł", ValueSLSL = "Prosim vnesite naslov", ValueTRTR = "Lütfen bir başlık giriniz", ValueZHCN = "请输入标题", ValueZHTW = "請輸入標題", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.date.required", ValueENUS = "Please select the start and end date", ValueFRFR = "Veuillez sélectionner la date de début et de fin", ValueHRHR = "Molimo odaberite datum početka i završetka", ValueKOKR = "시작일과 종료일을 선택하세요.", ValuePLPL = "Proszę podać datę początkową i końcową", ValueSLSL = "Izberite datum začetka in konca", ValueTRTR = "Lütfen başlangıç ve bitiş tarihini seçiniz", ValueZHCN = "请选择起止日期", ValueZHTW = "請選擇起止日期", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "common.delete", ValueENUS = "Delete", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "删除", ValueZHTW = "刪除", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "common.no-data", ValueENUS = "No Data", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "暂无数据", ValueZHTW = "暫無數據", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "common.captcha-btn.second", ValueENUS = "s", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "秒", ValueZHTW = "秒", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "common.captcha-btn.send", ValueENUS = "Send", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "发送", ValueZHTW = "發送", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.phone-number", ValueENUS = "Phone Number", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "手机号", ValueZHTW = "手機號", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.verification-code", ValueENUS = "Verification Code", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "验证码", ValueZHTW = "驗證碼", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "validation.password", ValueENUS = "Password", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "密码", ValueZHTW = "密碼", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.pagestyle", ValueENUS = "Page style setting", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "整体风格设置", ValueZHTW = "整體風格設定", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.pagestyle.dark", ValueENUS = "Dark style", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "暗色菜单风格", ValueZHTW = "暗色菜單風格", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.pagestyle.light", ValueENUS = "Light style", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "亮色菜单风格", ValueZHTW = "亮色菜單風格", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.content-width", ValueENUS = "Content Width", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "内容区域宽度", ValueZHTW = "內容區域寬度", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.content-width.fixed", ValueENUS = "Fixed", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "定宽", ValueZHTW = "定寬", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.content-width.fluid", ValueENUS = "Fluid", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "流式", ValueZHTW = "流式", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.themecolor", ValueENUS = "Theme Color", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "主题色", ValueZHTW = "主題色", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.themecolor.dust", ValueENUS = "Dust Red", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "薄暮", ValueZHTW = "薄暮", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.themecolor.volcano", ValueENUS = "Volcano", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "火山", ValueZHTW = "火山", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.themecolor.sunset", ValueENUS = "Sunset Orange", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "日暮", ValueZHTW = "日暮", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.themecolor.cyan", ValueENUS = "Cyan", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "明青", ValueZHTW = "明青", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.themecolor.green", ValueENUS = "Polar Green", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "极光绿", ValueZHTW = "極光綠", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.themecolor.daybreak", ValueENUS = "Daybreak Blue (default)", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "拂晓蓝（默认）", ValueZHTW = "拂曉藍（預設）", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.sidemenu", ValueENUS = "Side Menu Layout", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "侧边菜单布局", ValueZHTW = "側邊菜單佈局", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.topmenu", ValueENUS = "Top Menu Layout", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "顶部菜单布局", ValueZHTW = "頂部菜單佈局", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.fixedsidebar.hint", ValueENUS = "Works on Side Menu Layout", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "侧边菜单布局时可配置", ValueZHTW = "側邊菜單佈局時可配置", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.hideheader", ValueENUS = "Hidden Header when scrolling", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "下滑时隐藏 Header", ValueZHTW = "下滑時隱藏 Header", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.hideheader.hint", ValueENUS = "Works when Hidden Header is enabled", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "固定 Header 时可配置", ValueZHTW = "固定 Header 時可配置", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.onlyicon", ValueENUS = "Only icon", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "只显示图标", ValueZHTW = "隻顯示圖示", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.onlyicon.hint", ValueENUS = "Works on Top Menu Layout", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "顶部菜单布局时可配置", ValueZHTW = "頂部菜單佈局時可配置", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.othersettings", ValueENUS = "Other Settings", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "其他设置", ValueZHTW = "其他設定", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.weakmode", ValueENUS = "Weak Mode", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "色弱模式", ValueZHTW = "色弱模式", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.copy", ValueENUS = "Copy Setting", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "拷贝设置", ValueZHTW = "拷貝設定", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.copyinfo", ValueENUS = "Copy success, please replace it according to the contents of clipboard.", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "拷贝成功，请根据剪切板内容进行替换", ValueZHTW = "拷貝成功，請根據剪切闆內容進行替換", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.setting.production.hint", ValueENUS = "Setting panel shows in development environment only, please manually modify", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "配置栏只在开发环境用于预览，生产环境不会展现，请拷贝后手动修改配置文件", ValueZHTW = "配置欄隻在開發環境用於預覽，生産環境不會展現，請拷貝後手動修改配置文件", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "layout.pro.user.link.home", ValueENUS = "Pro Home", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "Pro 首页", ValueZHTW = "Pro 首頁", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "layout.pro.user.link.alain", ValueENUS = "Alain", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "Alain Pro", ValueZHTW = "Alain Pro", });
            this._context.BaseI18Ns.Add(new BaseI18N()
            {
                KeyName = "app.setting.copy.result",
                ValueENUS = "Configure in [src/styles/theme.less]:       {{ colorVars }Configure in [src / environments/*]:export const environment = {  ...  pro: {{{layoutVars}}  }}",
                ValueFRFR = "",
                ValueHRHR = "",
                ValueKOKR = "",
                ValuePLPL = "",
                ValueSLSL = "",
                ValueTRTR = "",
                ValueZHCN = "在 [src/styles/theme.less] 配置以下：{{colorVars}}在 [src/ environments/*] 的 pro 配置以下：export const environment = {  ...  pro: {{{layoutVars}}  }}",
                ValueZHTW = "在 [src/styles/theme.less] 配置以下：{{colorVars}}在 [src/environments/*] 的 pro 配置以下：export const environment = {... pro: {{{layoutVars}}    }     }",
            });


            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.dashboard.dd", ValueENUS = "Customize", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "定制", ValueZHTW = "定製", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.calendar", ValueENUS = "Calendar", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "日历", ValueZHTW = "日曆", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.calendar.basic", ValueENUS = "Basic Calendar", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "基本使用", ValueZHTW = "基本使用", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.calendar.list", ValueENUS = "List View", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "列表视图", ValueZHTW = "列錶視圖", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.calendar.events", ValueENUS = "Events", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "事件开发", ValueZHTW = "事件開發", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.faq", ValueENUS = "FAQ", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "常见问题", ValueZHTW = "常見問題", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.faq.v1", ValueENUS = "FAQ v1", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "常见问题 v1", ValueZHTW = "常見問題 v1", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.faq.v2", ValueENUS = "FAQ v2", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "常见问题 v2", ValueZHTW = "常見問題 v2", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.faq.v3", ValueENUS = "FAQ v3", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "常见问题 v3", ValueZHTW = "常見問題 v3", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.kanban-board", ValueENUS = "Kanban board", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "看板", ValueZHTW = "看闆", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.task", ValueENUS = "Tasks", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "任务", ValueZHTW = "任務", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.forum", ValueENUS = "Forums", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "论坛", ValueZHTW = "論壇", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.email", ValueENUS = "E-Mail", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "邮件消息", ValueZHTW = "郵件消息", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.project", ValueENUS = "Projects", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "项目", ValueZHTW = "項目", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.client", ValueENUS = "Clients", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "顾客", ValueZHTW = "顧客", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.contact", ValueENUS = "Contacts", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "联系人", ValueZHTW = "聯係人", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.pricing", ValueENUS = "Pricing", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "定价计划", ValueZHTW = "定價計畫", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.billing", ValueENUS = "Billing", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "账单", ValueZHTW = "賬單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.course", ValueENUS = "Courses", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "课程", ValueZHTW = "課程", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.chat", ValueENUS = "Chat", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "聊天窗口", ValueZHTW = "聊天視窗", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.gallery", ValueENUS = "Gallery", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "相册", ValueZHTW = "相冊", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.article", ValueENUS = "Articles", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "文章", ValueZHTW = "文章", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.voting", ValueENUS = "Voting", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "投票", ValueZHTW = "投票", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.other.invoice", ValueENUS = "Invoice", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "发票", ValueZHTW = "發票", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.settings", ValueENUS = "Settings", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "设置", ValueZHTW = "設定", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.pages", ValueENUS = "Pages", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "示例", ValueZHTW = "示例", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.ec", ValueENUS = "E-commerce", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "电商", ValueZHTW = "電商", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.ec.ware", ValueENUS = "Ware", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "商品", ValueZHTW = "商品", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.ec.trade", ValueENUS = "Trade", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "订单", ValueZHTW = "訂單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.file", ValueENUS = "File", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "文件", ValueZHTW = "文件", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.file.docx", ValueENUS = "Docx", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "Docx", ValueZHTW = "Docx", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.file.xlsx", ValueENUS = "Xlsx", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "Xlsx", ValueZHTW = "Xlsx", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.file.pdf", ValueENUS = "Pdf", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "Pdf", ValueZHTW = "Pdf", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.system", ValueENUS = "System", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "系统", ValueZHTW = "係統", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.system.file-manager", ValueENUS = "File Manager", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "文件管理", ValueZHTW = "文件管理", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.system.user", ValueENUS = "User", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "员工", ValueZHTW = "員工", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.system.role", ValueENUS = "Role", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "角色", ValueZHTW = "角色", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.system.permission", ValueENUS = "Permission", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "权限", ValueZHTW = "權限", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.system.log", ValueENUS = "Log", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "日志", ValueZHTW = "日誌", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.map", ValueENUS = "Maps", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "地图", ValueZHTW = "地圖", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.map.google", ValueENUS = "Google Maps", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "Google地图", ValueZHTW = "Google地圖", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.map.baidu", ValueENUS = "Baidu Maps", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "Baidu地图", ValueZHTW = "Baidu地圖", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.chart", ValueENUS = "Charts", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "图表", ValueZHTW = "圖錶", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.chart.g2", ValueENUS = "G2", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "G2", ValueZHTW = "G2", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.chart.ngx-charts", ValueENUS = "Ngx Charts", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "Ngx Charts", ValueZHTW = "Ngx Charts", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.chart.ngx-trend", ValueENUS = "Ngx Trend", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "Ngx Trend", ValueZHTW = "Ngx Trend", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.chart.mermaid", ValueENUS = "Mermaid", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "Mermaid", ValueZHTW = "Mermaid", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.chart.gantt", ValueENUS = "Gantt", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "甘特图", ValueZHTW = "甘特圖", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.account.lock", ValueENUS = "Lock", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "锁屏", ValueZHTW = "鎖屏", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.account.login", ValueENUS = "Login + Register", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "登录 + 注册", ValueZHTW = "登入 + 註冊", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.account.login2", ValueENUS = "Login + Register 2", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "登录 + 注册 2", ValueZHTW = "登入 + 註冊 2", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "menu.account.login3", ValueENUS = "Login + Register 3", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "登录 + 注册 3", ValueZHTW = "登入 + 註冊 3", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.sys.menu.list", ValueENUS = "Menu List", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "菜单列表", ValueZHTW = "菜單列錶", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.sys.menu.root", ValueENUS = "Add Root Menu", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "添加根目录", ValueZHTW = "添加根目錄", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "table.operation", ValueENUS = "operation", ValueFRFR = "Fonctionnement", ValueHRHR = "", ValueKOKR = "조작 하 다.", ValuePLPL = "działanie", ValueSLSL = "delovanje", ValueTRTR = "", ValueZHCN = "操作", ValueZHTW = "操作", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.form.edit.title", ValueENUS = "Edit Resource", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "修改资源", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.KeyName", ValueENUS = "Resource key value", ValueFRFR = "Valeur de la clé de ressource", ValueHRHR = "", ValueKOKR = "자원 키", ValuePLPL = "Wartość klucza zasobów", ValueSLSL = "Vrednost ključa vira", ValueTRTR = "", ValueZHCN = "资源键值", ValueZHTW = "資源鍵值", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueDEDE", ValueENUS = "German", ValueFRFR = "Allemand", ValueHRHR = "", ValueKOKR = "독일어", ValuePLPL = "Niemiecki", ValueSLSL = "nemško", ValueTRTR = "", ValueZHCN = "德语", ValueZHTW = "德語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.Dictionary.mnt", ValueENUS = "Dictionary management", ValueFRFR = "Gestion du dictionnaire", ValueHRHR = "", ValueKOKR = "사전 관리", ValuePLPL = "Zarządzanie słownikiem", ValueSLSL = "Upravljanje slovarjev", ValueTRTR = "", ValueZHCN = "字典管理", ValueZHTW = "字典管理", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.l.s.t.KeyName", ValueENUS = "Please enter the resource key name", ValueFRFR = "Veuillez saisir un nom de clé de ressource", ValueHRHR = "", ValueKOKR = "자원 키 워드 를 입력 하 세 요", ValuePLPL = "Proszę podać nazwę klucza zasobu", ValueSLSL = "Prosim vnesite ime ključa vira", ValueTRTR = "", ValueZHCN = "请输入资源键名", ValueZHTW = "請輸入資源鍵名", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.resoucemnt.i18n", ValueENUS = "internationalization", ValueFRFR = "Internationalisation", ValueHRHR = "", ValueKOKR = "국제 화", ValuePLPL = "internacjonalizacja", ValueSLSL = "internacionalizacija", ValueTRTR = "", ValueZHCN = "国际化", ValueZHTW = "國際化", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "message.save.success", ValueENUS = "Saved successfully", ValueFRFR = "Enregistrer avec succès", ValueHRHR = "", ValueKOKR = "저장 완료", ValuePLPL = "Zapisane pomyślnie", ValueSLSL = "Shranjeno uspešno", ValueTRTR = "", ValueZHCN = "保存成功", ValueZHTW = "保存成功", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "button.search", ValueENUS = "search", ValueFRFR = "Recherche", ValueHRHR = "", ValueKOKR = "수색 하 다.", ValuePLPL = "wyszukiwanie", ValueSLSL = "iskanje", ValueTRTR = "", ValueZHCN = "搜索", ValueZHTW = "蒐索", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "button.reset", ValueENUS = "Reset", ValueFRFR = "Réinitialiser", ValueHRHR = "", ValueKOKR = "초기 화", ValuePLPL = "Przywróć", ValueSLSL = "Ponastavi", ValueTRTR = "", ValueZHCN = "重置", ValueZHTW = "重置", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "button.save", ValueENUS = "save", ValueFRFR = "Enregistrer", ValueHRHR = "", ValueKOKR = "보존 하 다.", ValuePLPL = "konserwacja", ValueSLSL = "konzerviranje", ValueTRTR = "", ValueZHCN = "保存", ValueZHTW = "保存", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.orgmnt", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "机构管理", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.flow.mnt", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "流程管理", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "btn.cancel", ValueENUS = "cancel", ValueFRFR = "Annulation", ValueHRHR = "", ValueKOKR = "취소 하 다.", ValuePLPL = "Anuluj", ValueSLSL = "Prekliči", ValueTRTR = "", ValueZHCN = "取消", ValueZHTW = "取消", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValuePT", ValueENUS = "Portuguese", ValueFRFR = "Portugais", ValueHRHR = "", ValueKOKR = "포르투갈 어", ValuePLPL = "Portugalski", ValueSLSL = "portugalskoName", ValueTRTR = "", ValueZHCN = "葡萄牙语", ValueZHTW = "葡萄牙語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "button.auxiliary.translate", ValueENUS = "Auxiliary translation", ValueFRFR = "Traduction assistée", ValueHRHR = "", ValueKOKR = "보조 번역", ValuePLPL = "Tłumaczenie pomocnicze", ValueSLSL = "Pomožni prevod", ValueTRTR = "", ValueZHCN = "辅助翻译", ValueZHTW = "輔助翻譯", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueESES", ValueENUS = "Spanish", ValueFRFR = "Espagnol", ValueHRHR = "", ValueKOKR = "스페인어", ValuePLPL = "Hiszpański", ValueSLSL = "španščina", ValueTRTR = "", ValueZHCN = "西班牙语", ValueZHTW = "西班牙語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueENUS", ValueENUS = "English", ValueFRFR = "Anglais", ValueHRHR = "", ValueKOKR = "영어.", ValuePLPL = "AngielskiName", ValueSLSL = "Angleščina", ValueTRTR = "", ValueZHCN = "英语", ValueZHTW = "英語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueENGR", ValueENUS = "English", ValueFRFR = "Anglais", ValueHRHR = "", ValueKOKR = "영어.", ValuePLPL = "AngielskiName", ValueSLSL = "Angleščina", ValueTRTR = "", ValueZHCN = "英语", ValueZHTW = "英語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueELGR", ValueENUS = "Greek", ValueFRFR = "Grec", ValueHRHR = "", ValueKOKR = "그리스 어", ValuePLPL = "Greckie", ValueSLSL = "grščina", ValueTRTR = "", ValueZHCN = "希腊语", ValueZHTW = "希臘語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueFRFR", ValueENUS = "French", ValueFRFR = "Français", ValueHRHR = "", ValueKOKR = "프랑스어", ValuePLPL = "Francuski", ValueSLSL = "FrancoskoName", ValueTRTR = "", ValueZHCN = "法语", ValueZHTW = "法語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueHRHR", ValueENUS = "Croatian", ValueFRFR = "Croate", ValueHRHR = "", ValueKOKR = "크 로 아 티 아 어", ValuePLPL = "ChorwacjaName", ValueSLSL = "hrvaškoName", ValueTRTR = "", ValueZHCN = "克罗地亚语", ValueZHTW = "克羅地亞語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueITIT", ValueENUS = "Italian", ValueFRFR = "Italien", ValueHRHR = "", ValueKOKR = "이탈리아 어", ValuePLPL = "Włoskie", ValueSLSL = "ItalijanskoName", ValueTRTR = "", ValueZHCN = "意大利语", ValueZHTW = "義大利語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueJAJP", ValueENUS = "Japanese", ValueFRFR = "Japonais", ValueHRHR = "", ValueKOKR = "일본어", ValuePLPL = "Japoński", ValueSLSL = "Japonska", ValueTRTR = "", ValueZHCN = "日语", ValueZHTW = "日語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueKOKR", ValueENUS = "Korean", ValueFRFR = "Coréen", ValueHRHR = "", ValueKOKR = "한국어.", ValuePLPL = "Koreański", ValueSLSL = "KorejskoName", ValueTRTR = "", ValueZHCN = "韩语", ValueZHTW = "韓語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValuePLPL", ValueENUS = "Polish", ValueFRFR = "Polonais", ValueHRHR = "", ValueKOKR = "폴란드 어", ValuePLPL = "Polski", ValueSLSL = "poljščina", ValueTRTR = "", ValueZHCN = "波兰语", ValueZHTW = "波蘭語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueSLSL", ValueENUS = "Slovenian", ValueFRFR = "Slovène", ValueHRHR = "", ValueKOKR = "슬 로 베 니 아 어", ValuePLPL = "Słoweński", ValueSLSL = "SlovenskoName", ValueTRTR = "", ValueZHCN = "斯洛文尼亚语", ValueZHTW = "斯洛文尼亞語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueTRTR", ValueENUS = "Turkish", ValueFRFR = "Turc", ValueHRHR = "", ValueKOKR = "터키 어", ValuePLPL = "TureckiName", ValueSLSL = "Turščina", ValueTRTR = "", ValueZHCN = "土耳其语", ValueZHTW = "土耳其語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueZHCN", ValueENUS = "Simplified Chinese", ValueFRFR = "Chinois simplifié", ValueHRHR = "", ValueKOKR = "중국어 간 체", ValuePLPL = "Chiński uproszczony", ValueSLSL = "Poenostavljena kitajska", ValueTRTR = "", ValueZHCN = "简体中文", ValueZHTW = "簡體中文", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueZHTW", ValueENUS = "Traditional Chinese", ValueFRFR = "Chinois traditionnel", ValueHRHR = "", ValueKOKR = "번 체 중국어", ValuePLPL = "Tradycyjny chiński", ValueSLSL = "Tradicionalna kitajska", ValueTRTR = "", ValueZHCN = "繁体中文", ValueZHTW = "繁體中文", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueBG", ValueENUS = "Bulgarian", ValueFRFR = "Bulgare", ValueHRHR = "", ValueKOKR = "불가리아 어", ValuePLPL = "Bułgarski", ValueSLSL = "bolgarščina", ValueTRTR = "", ValueZHCN = "保加利亚语", ValueZHTW = "保加利亞語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueCS", ValueENUS = "Czech", ValueFRFR = "Tchèque", ValueHRHR = "", ValueKOKR = "체코 어", ValuePLPL = "Czechy", ValueSLSL = "Češka", ValueTRTR = "", ValueZHCN = "捷克语", ValueZHTW = "捷克語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueDA", ValueENUS = "Danish", ValueFRFR = "Danois", ValueHRHR = "", ValueKOKR = "덴마크 어", ValuePLPL = "Duński", ValueSLSL = "Danščina", ValueTRTR = "", ValueZHCN = "丹麦语", ValueZHTW = "丹麥語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueFI", ValueENUS = "Finnish", ValueFRFR = "Finnois", ValueHRHR = "", ValueKOKR = "핀란드 어", ValuePLPL = "Fiński", ValueSLSL = "Finščina", ValueTRTR = "", ValueZHCN = "芬兰语", ValueZHTW = "芬蘭語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueHU", ValueENUS = "Hungarian", ValueFRFR = "Hongrois", ValueHRHR = "", ValueKOKR = "헝가리 어", ValuePLPL = "Węgierski", ValueSLSL = "MadžarskoName", ValueTRTR = "", ValueZHCN = "匈牙利语", ValueZHTW = "匈牙利語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueNL", ValueENUS = "Dutch", ValueFRFR = "Néerlandais", ValueHRHR = "", ValueKOKR = "네덜란드 어", ValuePLPL = "Holenderski", ValueSLSL = "NizozemskaName", ValueTRTR = "", ValueZHCN = "荷兰语", ValueZHTW = "荷蘭語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.device.mnt", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "设备管理", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.resouce.mnt", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "资源管理", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueSR", ValueENUS = "Serb", ValueFRFR = "Serbe", ValueHRHR = "", ValueKOKR = "세 르 비 아 어", ValuePLPL = "SerbskiName", ValueSLSL = "Srb", ValueTRTR = "", ValueZHCN = "塞尔维亚语", ValueZHTW = "塞爾維亞語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueSV", ValueENUS = "Swedish", ValueFRFR = "Suédois", ValueHRHR = "", ValueKOKR = "스웨덴 어", ValuePLPL = "SzwedzkiName", ValueSLSL = "Švedska", ValueTRTR = "", ValueZHCN = "瑞典语", ValueZHTW = "瑞典語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueUK", ValueENUS = "Ukrainian", ValueFRFR = "Ukrainien", ValueHRHR = "", ValueKOKR = "우크라이나 어", ValuePLPL = "Ukraiński", ValueSLSL = "ukrajinskoName", ValueTRTR = "", ValueZHCN = "乌克兰语", ValueZHTW = "烏克蘭語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.ValueVI", ValueENUS = "Vietnamese", ValueFRFR = "Vietnamien", ValueHRHR = "", ValueKOKR = "베트남 어", ValuePLPL = "Wietnamski", ValueSLSL = "vietnamskoName", ValueTRTR = "", ValueZHCN = "越南语", ValueZHTW = "越南語", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "button.viewdetail", ValueENUS = "details", ValueFRFR = "Détails", ValueHRHR = "", ValueKOKR = "상세 한 상황.", ValuePLPL = "szczegóły", ValueSLSL = "podrobnosti", ValueTRTR = "", ValueZHCN = "详情", ValueZHTW = "詳情", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.devicetypemanage", ValueENUS = "Equipment model list", ValueFRFR = "Liste des modèles d'équipement", ValueHRHR = "", ValueKOKR = "설비 모델 리스트", ValuePLPL = "Wykaz modeli wyposażenia", ValueSLSL = "Seznam modelov opreme", ValueTRTR = "", ValueZHCN = "设备型号列表", ValueZHTW = "設備型號清單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.devicelistmanage", ValueENUS = "Equipment list", ValueFRFR = "Liste des équipements", ValueHRHR = "", ValueKOKR = "장치 목록", ValuePLPL = "Wykaz wyposażenia", ValueSLSL = "Seznam opreme", ValueTRTR = "", ValueZHCN = "设备列表", ValueZHTW = "設備清單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.devicemanufactor", ValueENUS = "Factory management", ValueFRFR = "Gestion du fabricant", ValueHRHR = "", ValueKOKR = "공장 관리", ValuePLPL = "Zarządzanie fabryką", ValueSLSL = "Upravljanje tovarne", ValueTRTR = "", ValueZHCN = "厂家管理", ValueZHTW = "廠家管理", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.DictionaryGroup.List", ValueENUS = "Dictionary group management", ValueFRFR = "Gestion des groupes de dictionnaires", ValueHRHR = "", ValueKOKR = "사전 그룹 관리", ValuePLPL = "Zarządzanie grupami słownikowymi", ValueSLSL = "Upravljanje slovarskih skupin", ValueTRTR = "", ValueZHCN = "字典分组管理", ValueZHTW = "字典分組管理", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.Dictionary.List", ValueENUS = "Dictionary management", ValueFRFR = "Gestion du dictionnaire", ValueHRHR = "", ValueKOKR = "사전 관리", ValuePLPL = "Zarządzanie słownikiem", ValueSLSL = "Upravljanje slovarjev", ValueTRTR = "", ValueZHCN = "字典管理", ValueZHTW = "字典管理", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.devicemanage", ValueENUS = "device management", ValueFRFR = "Gestion du matériel", ValueHRHR = "", ValueKOKR = "설비 관리", ValuePLPL = "zarządzanie urządzeniem", ValueSLSL = "upravljanje naprav", ValueTRTR = "", ValueZHCN = "设备管理", ValueZHTW = "設備管理", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "button.return", ValueENUS = "return", ValueFRFR = "Retour", ValueHRHR = "", ValueKOKR = "돌아가다", ValuePLPL = "powrót", ValueSLSL = "vračanje", ValueTRTR = "", ValueZHCN = "返回", ValueZHTW = "返回", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "common.propertiysettting", ValueENUS = "Property settings", ValueFRFR = "Paramètres de propriété", ValueHRHR = "", ValueKOKR = "속성 설정", ValuePLPL = "Ustawienia właściwości", ValueSLSL = "Nastavitve lastnosti", ValueTRTR = "", ValueZHCN = "属性设置", ValueZHTW = "内容設定", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "common.functionsetting", ValueENUS = "Function settings", ValueFRFR = "Paramètres fonctionnels", ValueHRHR = "", ValueKOKR = "기능 설정", ValuePLPL = "Ustawienia funkcji", ValueSLSL = "Nastavitve funkcij", ValueTRTR = "", ValueZHCN = "功能设置", ValueZHTW = "功能設置", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.authority.role.update", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "修改角色", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.authority.role.delete", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "删除角色", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.authority.role.save", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "保存角色", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.authority.function.delete", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "新增角色", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.authority.function.mnt", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "功能管理", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.dict.mnt", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "字典管理", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.member.mnt", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "会员管理", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.orglist", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "机构列表", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.newslist", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.authority.mnt", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "权限管理", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.userlist", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "人员列表", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.authority.role.mnt", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "角色管理", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.dev.paratp.detail", ValueENUS = "Usage details", ValueFRFR = "Détails de l'utilisation", ValueHRHR = "", ValueKOKR = "사용 상세", ValuePLPL = "Dane dotyczące użytkowania", ValueSLSL = "Podatki o uporabi", ValueTRTR = "", ValueZHCN = "使用详情", ValueZHTW = "使用詳情", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.dev.paratp.downlink", ValueENUS = "Parameter distribution", ValueFRFR = "Distribution des paramètres", ValueHRHR = "", ValueKOKR = "매개 변수 아래 발송", ValuePLPL = "Dystrybucja parametrów", ValueSLSL = "Porazdelitev parametrov", ValueTRTR = "", ValueZHCN = "参数下发", ValueZHTW = "參數下發", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "button.setting", ValueENUS = "set up", ValueFRFR = "Paramètres", ValueHRHR = "", ValueKOKR = "설치", ValuePLPL = "w górę", ValueSLSL = "pripravljena", ValueTRTR = "", ValueZHCN = "设置", ValueZHTW = "設定", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.resoucemnt", ValueENUS = "resource management", ValueFRFR = "Gestion des ressources", ValueHRHR = "", ValueKOKR = "자원 관리", ValuePLPL = "zarządzanie zasobami", ValueSLSL = "upravljanje virov", ValueTRTR = "", ValueZHCN = "资源管理", ValueZHTW = "資源管理", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.dev.paratp.setting", ValueENUS = "Parameter template setting", ValueFRFR = "Paramètres paramètres du modèle", ValueHRHR = "", ValueKOKR = "파라미터 템 플 릿 설정", ValuePLPL = "Ustawienie szablonu parametrów", ValueSLSL = "Nastavitev predloge parametrov", ValueTRTR = "", ValueZHCN = "参数模板设置", ValueZHTW = "參數範本設定", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.devtype.paramlist", ValueENUS = "Property settings", ValueFRFR = "Paramètres de propriété", ValueHRHR = "", ValueKOKR = "속성 설정", ValuePLPL = "Ustawienia właściwości", ValueSLSL = "Nastavitve lastnosti", ValueTRTR = "", ValueZHCN = "属性设置", ValueZHTW = "内容設定", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.dev.mnt.propsetting", ValueENUS = "Property settings", ValueFRFR = "Paramètres de propriété", ValueHRHR = "", ValueKOKR = "속성 설정", ValuePLPL = "Ustawienia właściwości", ValueSLSL = "Nastavitve lastnosti", ValueTRTR = "", ValueZHCN = "属性设置", ValueZHTW = "内容設定", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.routesmanage", ValueENUS = "Line management", ValueFRFR = "Gestion des itinéraires", ValueHRHR = "", ValueKOKR = "회선 관리", ValuePLPL = "Zarządzanie linią", ValueSLSL = "Upravljanje proge", ValueTRTR = "", ValueZHCN = "线路管理", ValueZHTW = "線路管理", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.memberlist", ValueENUS = "Membership list", ValueFRFR = "Liste des membres", ValueHRHR = "", ValueKOKR = "회원 리스트", ValuePLPL = "Lista członków", ValueSLSL = "Seznam članov", ValueTRTR = "", ValueZHCN = "会员列表", ValueZHTW = "會員列表", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.I18Nlist", ValueENUS = "International resource list", ValueFRFR = "Liste des ressources internationalisées", ValueHRHR = "", ValueKOKR = "국제 화 자원 리스트", ValuePLPL = "Międzynarodowy wykaz zasobów", ValueSLSL = "Mednarodni seznam virov", ValueTRTR = "", ValueZHCN = "国际化资源列表", ValueZHTW = "國際化資源清單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.dictgrouplist", ValueENUS = "Dictionary group list", ValueFRFR = "Liste des groupes de dictionnaires", ValueHRHR = "", ValueKOKR = "사전 분조 목록", ValuePLPL = "Lista grup słownikowych", ValueSLSL = "Seznam slovarskih skupin", ValueTRTR = "", ValueZHCN = "字典分组列表", ValueZHTW = "字典分組清單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.devicelist", ValueENUS = "Equipment list", ValueFRFR = "Liste des équipements", ValueHRHR = "", ValueKOKR = "장치 목록", ValuePLPL = "Wykaz wyposażenia", ValueSLSL = "Seznam opreme", ValueTRTR = "", ValueZHCN = "设备列表", ValueZHTW = "設備清單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.dictlist", ValueENUS = "Dictionary list", ValueFRFR = "Liste des dictionnaires", ValueHRHR = "", ValueKOKR = "사전 목록", ValuePLPL = "Lista słowników", ValueSLSL = "Seznam slovarjev", ValueTRTR = "", ValueZHCN = "字典列表", ValueZHTW = "字典清單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.articlelist", ValueENUS = "Column List ", ValueFRFR = "Liste des colonnes", ValueHRHR = "", ValueKOKR = "항목 목록", ValuePLPL = "Lista kolumn", ValueSLSL = "Seznam stolpcev", ValueTRTR = "", ValueZHCN = "栏目列表", ValueZHTW = "欄目清單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.workflowlist", ValueENUS = "Process list", ValueFRFR = "Liste des processus", ValueHRHR = "", ValueKOKR = "공정 리스트", ValuePLPL = "Lista procesów", ValueSLSL = "Seznam postopkov", ValueTRTR = "", ValueZHCN = "流程列表", ValueZHTW = "流程清單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.manufactorlist", ValueENUS = "List of manufacturers", ValueFRFR = "Liste des fabricants", ValueHRHR = "", ValueKOKR = "공장 리스트", ValuePLPL = "Wykaz producentów", ValueSLSL = "Seznam proizvajalcev", ValueTRTR = "", ValueZHCN = "厂家列表", ValueZHTW = "廠家清單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.devicetypelist", ValueENUS = "Equipment model list", ValueFRFR = "Liste des modèles d'équipement", ValueHRHR = "", ValueKOKR = "설비 모델 리스트", ValuePLPL = "Wykaz modeli wyposażenia", ValueSLSL = "Seznam modelov opreme", ValueTRTR = "", ValueZHCN = "设备型号列表", ValueZHTW = "設備型號清單", });
             this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "common.resourcesetting", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "角色资源设置", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "common.userrolesetting", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "用户角色设置", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "common.userfunctionsetting", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "用户功能设置", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "common.userassetsetting", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "用户资源设置", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "i18n.columns.Status", ValueENUS = "state", ValueFRFR = "Statut", ValueHRHR = "", ValueKOKR = "상태.", ValuePLPL = "stan", ValueSLSL = "stanje", ValueTRTR = "", ValueZHCN = "状态", ValueZHTW = "狀態", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.projectmanage", ValueENUS = "project management", ValueFRFR = "Gestion de projets", ValueHRHR = "", ValueKOKR = "프로젝트 관리", ValuePLPL = "zarządzanie projektem", ValueSLSL = "upravljanje projektov", ValueTRTR = "", ValueZHCN = "项目管理", ValueZHTW = "專案管理", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.workflow.project", ValueENUS = "Work order management", ValueFRFR = "Gestion des ordres de travail", ValueHRHR = "", ValueKOKR = "작업 명세서 관리", ValuePLPL = "Zarządzanie zamówieniami", ValueSLSL = "Upravljanje delovnega naročila", ValueTRTR = "", ValueZHCN = "工单管理", ValueZHTW = "工單管理", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.authority.role.setrolemodule", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "角色模块设置", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.authority.role.getrolemodule", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "获取角色模块", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.modulemnt.modulelist", ValueENUS = "Module management", ValueFRFR = "Gestion des modules", ValueHRHR = "", ValueKOKR = "모듈 관리", ValuePLPL = "Zarządzanie modułami", ValueSLSL = "Upravljanje modulov", ValueTRTR = "", ValueZHCN = "模块管理", ValueZHTW = "模塊管理", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.dynamicform.list", ValueENUS = "Dynamic form list", ValueFRFR = "Liste des formulaires dynamiques", ValueHRHR = "", ValueKOKR = "동적 폼 리스트", ValuePLPL = "Lista form dynamicznych", ValueSLSL = "Dinamični seznam oblik", ValueTRTR = "", ValueZHCN = "动态表单列表", ValueZHTW = "動態表單清單", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "mm.usermanage", ValueENUS = "", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "人员管理", ValueZHTW = "", });
            this._context.BaseI18Ns.Add(new BaseI18N() { KeyName = "app.register.install", ValueENUS = "install", ValueFRFR = "", ValueHRHR = "", ValueKOKR = "", ValuePLPL = "", ValueSLSL = "", ValueTRTR = "", ValueZHCN = "安装", ValueZHTW = "安装", });

            await this._context.SaveChangesAsync();
        }

        public async Task SeedDictionary()
        {
            var controltype = this._context.BaseDictionaryGroups.Add(new BaseDictionaryGroup { DictionaryGroupName = "控件类型",  DictionaryGroupStatus = 1});
            this._context.SaveChanges();
            var datatype = this._context.BaseDictionaryGroups.Add(new BaseDictionaryGroup { DictionaryGroupName = "数据类型", DictionaryGroupStatus = 1 });
            this._context.SaveChanges();

            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "bool", DictionaryTag = typeof(bool).FullName, DictionaryValue = "13", Dictionary18NKeyName = "dic.types.bool", DictionaryStatus = 1, DictionaryGroupId = datatype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "decimal[]", DictionaryTag = typeof(decimal[]).FullName, DictionaryValue = "12", Dictionary18NKeyName = "dic.types.decimalarray", DictionaryStatus = 1, DictionaryGroupId = datatype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "datetime[]", DictionaryTag = typeof(DateTime[]).FullName, DictionaryValue = "11", Dictionary18NKeyName = "dic.types.datetimearray", DictionaryStatus = 1, DictionaryGroupId = datatype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "single数组", DictionaryTag = typeof(Single[]).FullName, DictionaryValue = "10", Dictionary18NKeyName = "dic.types.singlearray", DictionaryStatus = 1, DictionaryGroupId = datatype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "single", DictionaryTag = typeof(Single[]).FullName, DictionaryValue = "9", Dictionary18NKeyName = "dic.types.single", DictionaryStatus = 1, DictionaryGroupId = datatype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "double数组", DictionaryTag = typeof(double[]).FullName, DictionaryValue = "8", Dictionary18NKeyName = "dic.types.doublearray", DictionaryStatus = 1, DictionaryGroupId = datatype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "string[]", DictionaryTag = typeof(string[]).FullName, DictionaryValue = "7", Dictionary18NKeyName = "dic.types.stringarray", DictionaryStatus = 1, DictionaryGroupId = datatype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "int[]", DictionaryTag = typeof(int[]).FullName, DictionaryValue = "6", Dictionary18NKeyName = "dic.types.intarray", DictionaryStatus = 1, DictionaryGroupId = datatype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "评分", DictionaryValue = "19", Dictionary18NKeyName = "dic.controltypes.rate", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "富文本编辑器", DictionaryValue = "18", Dictionary18NKeyName = "dic.controltypes.editor", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "多行文本", DictionaryValue = "17", Dictionary18NKeyName = "dic.controltypes.textarea", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "范围(数字)", DictionaryValue = "11", Dictionary18NKeyName = "dic.controltypes.range", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "文件上传", DictionaryValue = "16", Dictionary18NKeyName = "dic.controltypes.uploader", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "穿梭框", DictionaryValue = "15", Dictionary18NKeyName = "dic.controltypes.transfer", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "树形选择器", DictionaryValue = "14", Dictionary18NKeyName = "dic.controltypes.treeselect", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "monaco编辑器", DictionaryValue = "20", Dictionary18NKeyName = "dic.controltypes.monacoeditor", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });

            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "级联选择器", DictionaryValue = "13", Dictionary18NKeyName = "dic.controltypes.cascader", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "下拉列表(select)", DictionaryValue = "12", Dictionary18NKeyName = "dic.controltypes.select", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "文本框(markdown)", DictionaryValue = "4", Dictionary18NKeyName = "dic.controltypes.markdown", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "时间", DictionaryValue = "10", Dictionary18NKeyName = "dic.controltypes.time", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "日期", DictionaryValue = "9", Dictionary18NKeyName = "dic.controltypes.date", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "Radio单选", DictionaryValue = "8", Dictionary18NKeyName = "dic.controltypes.radioselect", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "布尔值(Radio)", DictionaryValue = "5", Dictionary18NKeyName = "dic.controltypes.radio", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "多选框", DictionaryValue = "6", Dictionary18NKeyName = "dic.controltypes.checkbox", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "数字", DictionaryValue = "1", Dictionary18NKeyName = "dic.controltypes.number", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "文本框", DictionaryValue = "2", Dictionary18NKeyName = "dic.controltypes.textbox", DictionaryStatus = 1, DictionaryGroupId = controltype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "DateTime", DictionaryTag = typeof(DateTime).FullName, DictionaryValue = "5", Dictionary18NKeyName = "dic.types.DateTime", DictionaryStatus = 1, DictionaryGroupId = datatype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "string", DictionaryTag = typeof(string).FullName, DictionaryValue = "4", Dictionary18NKeyName = "dic.types.string", DictionaryStatus = 1, DictionaryGroupId = datatype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "decimal", DictionaryTag = typeof(decimal).FullName, DictionaryValue = "3", Dictionary18NKeyName = "dic.types.decimal", DictionaryStatus = 1, DictionaryGroupId = datatype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "double", DictionaryTag = typeof(double).FullName, DictionaryValue = "2", Dictionary18NKeyName = "dic.types.double", DictionaryStatus = 1, DictionaryGroupId = datatype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "int", DictionaryTag = typeof(int).FullName, DictionaryValue = "1", Dictionary18NKeyName = "dic.types.int", DictionaryStatus = 1, DictionaryGroupId = datatype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            //唯一的自定义类型
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "文件数组", DictionaryTag = typeof(NzUploadFile[]).FullName, DictionaryValue = "14", Dictionary18NKeyName = "dic.types.filearray", DictionaryStatus = 1, DictionaryGroupId = datatype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "DateTimeOffset", DictionaryTag = typeof(DateTimeOffset).FullName, DictionaryValue = "15", Dictionary18NKeyName = "dic.types.datetimeoffset", DictionaryStatus = 1, DictionaryGroupId = datatype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });
            this._context.BaseDictionaries.Add(new BaseDictionary { DictionaryName = "DateTimeOffset[]", DictionaryTag = typeof(DateTimeOffset[]).FullName, DictionaryValue = "16", Dictionary18NKeyName = "dic.types.datetimeoffsetarray", DictionaryStatus = 1, DictionaryGroupId = datatype.Entity.DictionaryGroupId, DictionaryDesc = "", DictionaryIcon = "" });

            await this._context.SaveChangesAsync();

        }


        public async Task SeedUserAsync(InstallDto model)
        {
            var tenant = _context.Tenant.FirstOrDefault(t => t.EMail == model.TenantEMail);
            var customer = _context.Customer.FirstOrDefault(t => t.Email == model.CustomerEMail);
            if (tenant == null && customer == null)
            {
                tenant = new Tenant() { Id = Guid.NewGuid(), Name = model.TenantName, EMail = model.TenantEMail };
                customer = new Customer() { Id = Guid.NewGuid(), Name = model.CustomerName, Email = model.CustomerEMail };
                customer.Tenant = tenant;
                tenant.Customers = new List<Customer>();
                tenant.Customers.Add(customer);
                _context.Tenant.Add(tenant);
                _context.Customer.Add(customer);
                await _context.SaveChangesAsync();
            }
            IdentityUser user = await _userManager.FindByEmailAsync(model.Email);
            if (user == null)
            {
                user = new IdentityUser
                {
                    Email = model.Email,
                    UserName = model.Email,
                    PhoneNumber = model.PhoneNumber
                };
                var result = await _userManager.CreateAsync(user, model.Password);
                if (result.Succeeded)
                {
                    await _signInManager.SignInAsync(user, false);
                    await _signInManager.UserManager.AddClaimAsync(user, new Claim(ClaimTypes.Email, model.Email));
                    await _signInManager.UserManager.AddClaimAsync(user, new Claim(IoTSharpClaimTypes.Customer, customer.Id.ToString()));
                    await _signInManager.UserManager.AddClaimAsync(user, new Claim(IoTSharpClaimTypes.Tenant, tenant.Id.ToString()));
                    await _signInManager.UserManager.AddToRoleAsync(user, nameof(UserRole.Anonymous));
                    await _signInManager.UserManager.AddToRoleAsync(user, nameof(UserRole.NormalUser));
                    await _signInManager.UserManager.AddToRoleAsync(user, nameof(UserRole.CustomerAdmin));
                    await _signInManager.UserManager.AddToRoleAsync(user, nameof(UserRole.TenantAdmin));
                    await _signInManager.UserManager.AddToRoleAsync(user, nameof(UserRole.SystemAdmin));

                }
                else
                {
                    throw new Exception(string.Join(',', result.Errors.ToList().Select(ie => $"code={ie.Code},msg={ie.Description}")));
                }
            }
            var rship = new Relationship
            {
                IdentityUser = _context.Users.Find(user.Id),
                Customer = _context.Customer.Find(customer.Id),
                Tenant = _context.Tenant.Find(tenant.Id)
            };
            _context.Add(rship);
            await _context.SaveChangesAsync();
        }
    }
}